/*!
 * @kurkle/color v0.3.4
 * https://github.com/kurkle/color#readme
 * (c) 2024 Jukka Kurkela
 * Released under the MIT License
 */
function round(v) {
  return v + 0.5 | 0;
}
const lim = (v, l, h) => Math.max(Math.min(v, h), l);
function p2b(v) {
  return lim(round(v * 2.55), 0, 255);
}
function n2b(v) {
  return lim(round(v * 255), 0, 255);
}
function b2n(v) {
  return lim(round(v / 2.55) / 100, 0, 1);
}
function n2p(v) {
  return lim(round(v * 100), 0, 100);
}
const map$1 = {
  0: 0,
  1: 1,
  2: 2,
  3: 3,
  4: 4,
  5: 5,
  6: 6,
  7: 7,
  8: 8,
  9: 9,
  A: 10,
  B: 11,
  C: 12,
  D: 13,
  E: 14,
  F: 15,
  a: 10,
  b: 11,
  c: 12,
  d: 13,
  e: 14,
  f: 15
};
const hex = [...`\u0030\u0031\u0032\u0033\u0034\u0035\u0036\u0037\u0038\u0039\u0041\u0042\u0043\u0044\u0045\u0046`];
const h1 = b => hex[b & 15];
const h2 = b => hex[(b & 240) >> 4] + hex[b & 15];
const eq = b => (b & 240) >> 4 === (b & 15);
const isShort = v => eq(v.r) && eq(v.g) && eq(v.b) && eq(v.a);
function hexParse(str) {
  var len = str.length;
  var ret;
  if (str[0] === `\u0023`) {
    if (len === 4 || len === 5) {
      ret = {
        r: 255 & map$1[str[1]] * 17,
        g: 255 & map$1[str[2]] * 17,
        b: 255 & map$1[str[3]] * 17,
        a: len === 5 ? map$1[str[4]] * 17 : 255
      };
    } else if (len === 7 || len === 9) {
      ret = {
        r: map$1[str[1]] << 4 | map$1[str[2]],
        g: map$1[str[3]] << 4 | map$1[str[4]],
        b: map$1[str[5]] << 4 | map$1[str[6]],
        a: len === 9 ? map$1[str[7]] << 4 | map$1[str[8]] : 255
      };
    }
  }
  return ret;
}
const alpha = (a, f) => a < 255 ? f(a) : ``;
function hexString(v) {
  var f = isShort(v) ? h1 : h2;
  return v ? `\u0023` + f(v.r) + f(v.g) + f(v.b) + alpha(v.a, f) : void 0;
}
const HUE_RE = /^(hsla?|hwb|hsv)\(\s*([-+.e\d]+)(?:deg)?[\s,]+([-+.e\d]+)%[\s,]+([-+.e\d]+)%(?:[\s,]+([-+.e\d]+)(%)?)?\s*\)$/;
function hsl2rgbn(h, s, l) {
  const a = s * Math.min(l, 1 - l);
  const f = (n, k = (n + h / 30) % 12) => l - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
  return [f(0), f(8), f(4)];
}
function hsv2rgbn(h, s, v) {
  const f = (n, k = (n + h / 60) % 6) => v - v * s * Math.max(Math.min(k, 4 - k, 1), 0);
  return [f(5), f(3), f(1)];
}
function hwb2rgbn(h, w, b) {
  const rgb = hsl2rgbn(h, 1, 0.5);
  let i;
  if (w + b > 1) {
    i = 1 / (w + b);
    w *= i;
    b *= i;
  }
  for (i = 0; i < 3; i++) {
    rgb[i] *= 1 - w - b;
    rgb[i] += w;
  }
  return rgb;
}
function hueValue(r, g, b, d, max) {
  if (r === max) {
    return (g - b) / d + (g < b ? 6 : 0);
  }
  if (g === max) {
    return (b - r) / d + 2;
  }
  return (r - g) / d + 4;
}
function rgb2hsl(v) {
  const range = 255;
  const r = v.r / range;
  const g = v.g / range;
  const b = v.b / range;
  const max = Math.max(r, g, b);
  const min = Math.min(r, g, b);
  const l = (max + min) / 2;
  let h, s, d;
  if (max !== min) {
    d = max - min;
    s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
    h = hueValue(r, g, b, d, max);
    h = h * 60 + 0.5;
  }
  return [h | 0, s || 0, l];
}
function calln(f, a, b, c) {
  return (Array.isArray(a) ? f(a[0], a[1], a[2]) : f(a, b, c)).map(n2b);
}
function hsl2rgb(h, s, l) {
  return calln(hsl2rgbn, h, s, l);
}
function hwb2rgb(h, w, b) {
  return calln(hwb2rgbn, h, w, b);
}
function hsv2rgb(h, s, v) {
  return calln(hsv2rgbn, h, s, v);
}
function hue(h) {
  return (h % 360 + 360) % 360;
}
function hueParse(str) {
  const m = HUE_RE.exec(str);
  let a = 255;
  let v;
  if (!m) {
    return;
  }
  if (m[5] !== v) {
    a = m[6] ? p2b(+m[5]) : n2b(+m[5]);
  }
  const h = hue(+m[2]);
  const p1 = +m[3] / 100;
  const p2 = +m[4] / 100;
  if (m[1] === `\u0068\u0077\u0062`) {
    v = hwb2rgb(h, p1, p2);
  } else if (m[1] === `\u0068\u0073\u0076`) {
    v = hsv2rgb(h, p1, p2);
  } else {
    v = hsl2rgb(h, p1, p2);
  }
  return {
    r: v[0],
    g: v[1],
    b: v[2],
    a
  };
}
function rotate(v, deg) {
  var h = rgb2hsl(v);
  h[0] = hue(h[0] + deg);
  h = hsl2rgb(h);
  v.r = h[0];
  v.g = h[1];
  v.b = h[2];
}
function hslString(v) {
  if (!v) {
    return;
  }
  const a = rgb2hsl(v);
  const h = a[0];
  const s = n2p(a[1]);
  const l = n2p(a[2]);
  return v.a < 255 ? `\u0068\u0073\u006c\u0061\u0028${h}\u002c\u0020${s}\u0025\u002c\u0020${l}\u0025\u002c\u0020${b2n(v.a)}\u0029` : `\u0068\u0073\u006c\u0028${h}\u002c\u0020${s}\u0025\u002c\u0020${l}\u0025\u0029`;
}
const map = {
  x: `\u0064\u0061\u0072\u006b`,
  Z: `\u006c\u0069\u0067\u0068\u0074`,
  Y: `\u0072\u0065`,
  X: `\u0062\u006c\u0075`,
  W: `\u0067\u0072`,
  V: `\u006d\u0065\u0064\u0069\u0075\u006d`,
  U: `\u0073\u006c\u0061\u0074\u0065`,
  A: `\u0065\u0065`,
  T: `\u006f\u006c`,
  S: `\u006f\u0072`,
  B: `\u0072\u0061`,
  C: `\u006c\u0061\u0074\u0065\u0067`,
  D: `\u0069\u0067\u0068\u0074\u0073`,
  R: `\u0069\u006e`,
  Q: `\u0074\u0075\u0072\u0071\u0075\u006f\u0069\u0073`,
  E: `\u0068\u0069`,
  P: `\u0072\u006f`,
  O: `\u0061\u006c`,
  N: `\u006c\u0065`,
  M: `\u0064\u0065`,
  L: `\u0079\u0065\u006c\u006c\u006f`,
  F: `\u0065\u006e`,
  K: `\u0063\u0068`,
  G: `\u0061\u0072\u006b\u0073`,
  H: `\u0065\u0061`,
  I: `\u0069\u0067\u0068\u0074\u0067`,
  J: `\u0077\u0068`
};
const names$1 = {
  OiceXe: `\u0066\u0030\u0066\u0038\u0066\u0066`,
  antiquewEte: `\u0066\u0061\u0065\u0062\u0064\u0037`,
  aqua: `\u0066\u0066\u0066\u0066`,
  aquamarRe: `\u0037\u0066\u0066\u0066\u0064\u0034`,
  azuY: `\u0066\u0030\u0066\u0066\u0066\u0066`,
  beige: `\u0066\u0035\u0066\u0035\u0064\u0063`,
  bisque: `\u0066\u0066\u0065\u0034\u0063\u0034`,
  black: `\u0030`,
  blanKedOmond: `\u0066\u0066\u0065\u0062\u0063\u0064`,
  Xe: `\u0066\u0066`,
  XeviTet: `\u0038\u0061\u0032\u0062\u0065\u0032`,
  bPwn: `\u0061\u0035\u0032\u0061\u0032\u0061`,
  burlywood: `\u0064\u0065\u0062\u0038\u0038\u0037`,
  caMtXe: `\u0035\u0066\u0039\u0065\u0061\u0030`,
  KartYuse: `\u0037\u0066\u0066\u0066\u0030\u0030`,
  KocTate: `\u0064\u0032\u0036\u0039\u0031\u0065`,
  cSO: `\u0066\u0066\u0037\u0066\u0035\u0030`,
  cSnflowerXe: `\u0036\u0034\u0039\u0035\u0065\u0064`,
  cSnsilk: `\u0066\u0066\u0066\u0038\u0064\u0063`,
  crimson: `\u0064\u0063\u0031\u0034\u0033\u0063`,
  cyan: `\u0066\u0066\u0066\u0066`,
  xXe: `\u0038\u0062`,
  xcyan: `\u0038\u0062\u0038\u0062`,
  xgTMnPd: `\u0062\u0038\u0038\u0036\u0030\u0062`,
  xWay: `\u0061\u0039\u0061\u0039\u0061\u0039`,
  xgYF: `\u0036\u0034\u0030\u0030`,
  xgYy: `\u0061\u0039\u0061\u0039\u0061\u0039`,
  xkhaki: `\u0062\u0064\u0062\u0037\u0036\u0062`,
  xmagFta: `\u0038\u0062\u0030\u0030\u0038\u0062`,
  xTivegYF: `\u0035\u0035\u0036\u0062\u0032\u0066`,
  xSange: `\u0066\u0066\u0038\u0063\u0030\u0030`,
  xScEd: `\u0039\u0039\u0033\u0032\u0063\u0063`,
  xYd: `\u0038\u0062\u0030\u0030\u0030\u0030`,
  xsOmon: `\u0065\u0039\u0039\u0036\u0037\u0061`,
  xsHgYF: `\u0038\u0066\u0062\u0063\u0038\u0066`,
  xUXe: `\u0034\u0038\u0033\u0064\u0038\u0062`,
  xUWay: `\u0032\u0066\u0034\u0066\u0034\u0066`,
  xUgYy: `\u0032\u0066\u0034\u0066\u0034\u0066`,
  xQe: `\u0063\u0065\u0064\u0031`,
  xviTet: `\u0039\u0034\u0030\u0030\u0064\u0033`,
  dAppRk: `\u0066\u0066\u0031\u0034\u0039\u0033`,
  dApskyXe: `\u0062\u0066\u0066\u0066`,
  dimWay: `\u0036\u0039\u0036\u0039\u0036\u0039`,
  dimgYy: `\u0036\u0039\u0036\u0039\u0036\u0039`,
  dodgerXe: `\u0031\u0065\u0039\u0030\u0066\u0066`,
  fiYbrick: `\u0062\u0032\u0032\u0032\u0032\u0032`,
  flSOwEte: `\u0066\u0066\u0066\u0061\u0066\u0030`,
  foYstWAn: `\u0032\u0032\u0038\u0062\u0032\u0032`,
  fuKsia: `\u0066\u0066\u0030\u0030\u0066\u0066`,
  gaRsbSo: `\u0064\u0063\u0064\u0063\u0064\u0063`,
  ghostwEte: `\u0066\u0038\u0066\u0038\u0066\u0066`,
  gTd: `\u0066\u0066\u0064\u0037\u0030\u0030`,
  gTMnPd: `\u0064\u0061\u0061\u0035\u0032\u0030`,
  Way: `\u0038\u0030\u0038\u0030\u0038\u0030`,
  gYF: `\u0038\u0030\u0030\u0030`,
  gYFLw: `\u0061\u0064\u0066\u0066\u0032\u0066`,
  gYy: `\u0038\u0030\u0038\u0030\u0038\u0030`,
  honeyMw: `\u0066\u0030\u0066\u0066\u0066\u0030`,
  hotpRk: `\u0066\u0066\u0036\u0039\u0062\u0034`,
  RdianYd: `\u0063\u0064\u0035\u0063\u0035\u0063`,
  Rdigo: `\u0034\u0062\u0030\u0030\u0038\u0032`,
  ivSy: `\u0066\u0066\u0066\u0066\u0066\u0030`,
  khaki: `\u0066\u0030\u0065\u0036\u0038\u0063`,
  lavFMr: `\u0065\u0036\u0065\u0036\u0066\u0061`,
  lavFMrXsh: `\u0066\u0066\u0066\u0030\u0066\u0035`,
  lawngYF: `\u0037\u0063\u0066\u0063\u0030\u0030`,
  NmoncEffon: `\u0066\u0066\u0066\u0061\u0063\u0064`,
  ZXe: `\u0061\u0064\u0064\u0038\u0065\u0036`,
  ZcSO: `\u0066\u0030\u0038\u0030\u0038\u0030`,
  Zcyan: `\u0065\u0030\u0066\u0066\u0066\u0066`,
  ZgTMnPdLw: `\u0066\u0061\u0066\u0061\u0064\u0032`,
  ZWay: `\u0064\u0033\u0064\u0033\u0064\u0033`,
  ZgYF: `\u0039\u0030\u0065\u0065\u0039\u0030`,
  ZgYy: `\u0064\u0033\u0064\u0033\u0064\u0033`,
  ZpRk: `\u0066\u0066\u0062\u0036\u0063\u0031`,
  ZsOmon: `\u0066\u0066\u0061\u0030\u0037\u0061`,
  ZsHgYF: `\u0032\u0030\u0062\u0032\u0061\u0061`,
  ZskyXe: `\u0038\u0037\u0063\u0065\u0066\u0061`,
  ZUWay: `\u0037\u0037\u0038\u0038\u0039\u0039`,
  ZUgYy: `\u0037\u0037\u0038\u0038\u0039\u0039`,
  ZstAlXe: `\u0062\u0030\u0063\u0034\u0064\u0065`,
  ZLw: `\u0066\u0066\u0066\u0066\u0065\u0030`,
  lime: `\u0066\u0066\u0030\u0030`,
  limegYF: `\u0033\u0032\u0063\u0064\u0033\u0032`,
  lRF: `\u0066\u0061\u0066\u0030\u0065\u0036`,
  magFta: `\u0066\u0066\u0030\u0030\u0066\u0066`,
  maPon: `\u0038\u0030\u0030\u0030\u0030\u0030`,
  VaquamarRe: `\u0036\u0036\u0063\u0064\u0061\u0061`,
  VXe: `\u0063\u0064`,
  VScEd: `\u0062\u0061\u0035\u0035\u0064\u0033`,
  VpurpN: `\u0039\u0033\u0037\u0030\u0064\u0062`,
  VsHgYF: `\u0033\u0063\u0062\u0033\u0037\u0031`,
  VUXe: `\u0037\u0062\u0036\u0038\u0065\u0065`,
  VsprRggYF: `\u0066\u0061\u0039\u0061`,
  VQe: `\u0034\u0038\u0064\u0031\u0063\u0063`,
  VviTetYd: `\u0063\u0037\u0031\u0035\u0038\u0035`,
  midnightXe: `\u0031\u0039\u0031\u0039\u0037\u0030`,
  mRtcYam: `\u0066\u0035\u0066\u0066\u0066\u0061`,
  mistyPse: `\u0066\u0066\u0065\u0034\u0065\u0031`,
  moccasR: `\u0066\u0066\u0065\u0034\u0062\u0035`,
  navajowEte: `\u0066\u0066\u0064\u0065\u0061\u0064`,
  navy: `\u0038\u0030`,
  Tdlace: `\u0066\u0064\u0066\u0035\u0065\u0036`,
  Tive: `\u0038\u0030\u0038\u0030\u0030\u0030`,
  TivedBb: `\u0036\u0062\u0038\u0065\u0032\u0033`,
  Sange: `\u0066\u0066\u0061\u0035\u0030\u0030`,
  SangeYd: `\u0066\u0066\u0034\u0035\u0030\u0030`,
  ScEd: `\u0064\u0061\u0037\u0030\u0064\u0036`,
  pOegTMnPd: `\u0065\u0065\u0065\u0038\u0061\u0061`,
  pOegYF: `\u0039\u0038\u0066\u0062\u0039\u0038`,
  pOeQe: `\u0061\u0066\u0065\u0065\u0065\u0065`,
  pOeviTetYd: `\u0064\u0062\u0037\u0030\u0039\u0033`,
  papayawEp: `\u0066\u0066\u0065\u0066\u0064\u0035`,
  pHKpuff: `\u0066\u0066\u0064\u0061\u0062\u0039`,
  peru: `\u0063\u0064\u0038\u0035\u0033\u0066`,
  pRk: `\u0066\u0066\u0063\u0030\u0063\u0062`,
  plum: `\u0064\u0064\u0061\u0030\u0064\u0064`,
  powMrXe: `\u0062\u0030\u0065\u0030\u0065\u0036`,
  purpN: `\u0038\u0030\u0030\u0030\u0038\u0030`,
  YbeccapurpN: `\u0036\u0036\u0033\u0033\u0039\u0039`,
  Yd: `\u0066\u0066\u0030\u0030\u0030\u0030`,
  Psybrown: `\u0062\u0063\u0038\u0066\u0038\u0066`,
  PyOXe: `\u0034\u0031\u0036\u0039\u0065\u0031`,
  saddNbPwn: `\u0038\u0062\u0034\u0035\u0031\u0033`,
  sOmon: `\u0066\u0061\u0038\u0030\u0037\u0032`,
  sandybPwn: `\u0066\u0034\u0061\u0034\u0036\u0030`,
  sHgYF: `\u0032\u0065\u0038\u0062\u0035\u0037`,
  sHshell: `\u0066\u0066\u0066\u0035\u0065\u0065`,
  siFna: `\u0061\u0030\u0035\u0032\u0032\u0064`,
  silver: `\u0063\u0030\u0063\u0030\u0063\u0030`,
  skyXe: `\u0038\u0037\u0063\u0065\u0065\u0062`,
  UXe: `\u0036\u0061\u0035\u0061\u0063\u0064`,
  UWay: `\u0037\u0030\u0038\u0030\u0039\u0030`,
  UgYy: `\u0037\u0030\u0038\u0030\u0039\u0030`,
  snow: `\u0066\u0066\u0066\u0061\u0066\u0061`,
  sprRggYF: `\u0066\u0066\u0037\u0066`,
  stAlXe: `\u0034\u0036\u0038\u0032\u0062\u0034`,
  tan: `\u0064\u0032\u0062\u0034\u0038\u0063`,
  teO: `\u0038\u0030\u0038\u0030`,
  tEstN: `\u0064\u0038\u0062\u0066\u0064\u0038`,
  tomato: `\u0066\u0066\u0036\u0033\u0034\u0037`,
  Qe: `\u0034\u0030\u0065\u0030\u0064\u0030`,
  viTet: `\u0065\u0065\u0038\u0032\u0065\u0065`,
  JHt: `\u0066\u0035\u0064\u0065\u0062\u0033`,
  wEte: `\u0066\u0066\u0066\u0066\u0066\u0066`,
  wEtesmoke: `\u0066\u0035\u0066\u0035\u0066\u0035`,
  Lw: `\u0066\u0066\u0066\u0066\u0030\u0030`,
  LwgYF: `\u0039\u0061\u0063\u0064\u0033\u0032`
};
function unpack() {
  const unpacked = {};
  const keys = Object.keys(names$1);
  const tkeys = Object.keys(map);
  let i, j, k, ok, nk;
  for (i = 0; i < keys.length; i++) {
    ok = nk = keys[i];
    for (j = 0; j < tkeys.length; j++) {
      k = tkeys[j];
      nk = nk.replace(k, map[k]);
    }
    k = parseInt(names$1[ok], 16);
    unpacked[nk] = [k >> 16 & 255, k >> 8 & 255, k & 255];
  }
  return unpacked;
}
let names;
function nameParse(str) {
  if (!names) {
    names = unpack();
    names.transparent = [0, 0, 0, 0];
  }
  const a = names[str.toLowerCase()];
  return a && {
    r: a[0],
    g: a[1],
    b: a[2],
    a: a.length === 4 ? a[3] : 255
  };
}
const RGB_RE = /^rgba?\(\s*([-+.\d]+)(%)?[\s,]+([-+.e\d]+)(%)?[\s,]+([-+.e\d]+)(%)?(?:[\s,/]+([-+.e\d]+)(%)?)?\s*\)$/;
function rgbParse(str) {
  const m = RGB_RE.exec(str);
  let a = 255;
  let r, g, b;
  if (!m) {
    return;
  }
  if (m[7] !== r) {
    const v = +m[7];
    a = m[8] ? p2b(v) : lim(v * 255, 0, 255);
  }
  r = +m[1];
  g = +m[3];
  b = +m[5];
  r = 255 & (m[2] ? p2b(r) : lim(r, 0, 255));
  g = 255 & (m[4] ? p2b(g) : lim(g, 0, 255));
  b = 255 & (m[6] ? p2b(b) : lim(b, 0, 255));
  return {
    r,
    g,
    b,
    a
  };
}
function rgbString(v) {
  return v && (v.a < 255 ? `\u0072\u0067\u0062\u0061\u0028${v.r}\u002c\u0020${v.g}\u002c\u0020${v.b}\u002c\u0020${b2n(v.a)}\u0029` : `\u0072\u0067\u0062\u0028${v.r}\u002c\u0020${v.g}\u002c\u0020${v.b}\u0029`);
}
const to = v => v <= 31308e-7 ? v * 12.92 : Math.pow(v, 1 / 2.4) * 1.055 - 0.055;
const from = v => v <= 0.04045 ? v / 12.92 : Math.pow((v + 0.055) / 1.055, 2.4);
function interpolate(rgb1, rgb2, t) {
  const r = from(b2n(rgb1.r));
  const g = from(b2n(rgb1.g));
  const b = from(b2n(rgb1.b));
  return {
    r: n2b(to(r + t * (from(b2n(rgb2.r)) - r))),
    g: n2b(to(g + t * (from(b2n(rgb2.g)) - g))),
    b: n2b(to(b + t * (from(b2n(rgb2.b)) - b))),
    a: rgb1.a + t * (rgb2.a - rgb1.a)
  };
}
function modHSL(v, i, ratio) {
  if (v) {
    let tmp = rgb2hsl(v);
    tmp[i] = Math.max(0, Math.min(tmp[i] + tmp[i] * ratio, i === 0 ? 360 : 1));
    tmp = hsl2rgb(tmp);
    v.r = tmp[0];
    v.g = tmp[1];
    v.b = tmp[2];
  }
}
function clone(v, proto) {
  return v ? Object.assign(proto || {}, v) : v;
}
function fromObject(input) {
  var v = {
    r: 0,
    g: 0,
    b: 0,
    a: 255
  };
  if (Array.isArray(input)) {
    if (input.length >= 3) {
      v = {
        r: input[0],
        g: input[1],
        b: input[2],
        a: 255
      };
      if (input.length > 3) {
        v.a = n2b(input[3]);
      }
    }
  } else {
    v = clone(input, {
      r: 0,
      g: 0,
      b: 0,
      a: 1
    });
    v.a = n2b(v.a);
  }
  return v;
}
function functionParse(str) {
  if (str.charAt(0) === `\u0072`) {
    return rgbParse(str);
  }
  return hueParse(str);
}
class Color {
  constructor(input) {
    if (input instanceof Color) {
      return input;
    }
    const type = typeof input;
    let v;
    if (type === `\u006f\u0062\u006a\u0065\u0063\u0074`) {
      v = fromObject(input);
    } else if (type === `\u0073\u0074\u0072\u0069\u006e\u0067`) {
      v = hexParse(input) || nameParse(input) || functionParse(input);
    }
    this._rgb = v;
    this._valid = !!v;
  }
  get valid() {
    return this._valid;
  }
  get rgb() {
    var v = clone(this._rgb);
    if (v) {
      v.a = b2n(v.a);
    }
    return v;
  }
  set rgb(obj) {
    this._rgb = fromObject(obj);
  }
  rgbString() {
    return this._valid ? rgbString(this._rgb) : void 0;
  }
  hexString() {
    return this._valid ? hexString(this._rgb) : void 0;
  }
  hslString() {
    return this._valid ? hslString(this._rgb) : void 0;
  }
  mix(color, weight) {
    if (color) {
      const c1 = this.rgb;
      const c2 = color.rgb;
      let w2;
      const p = weight === w2 ? 0.5 : weight;
      const w = 2 * p - 1;
      const a = c1.a - c2.a;
      const w1 = ((w * a === -1 ? w : (w + a) / (1 + w * a)) + 1) / 2;
      w2 = 1 - w1;
      c1.r = 255 & w1 * c1.r + w2 * c2.r + 0.5;
      c1.g = 255 & w1 * c1.g + w2 * c2.g + 0.5;
      c1.b = 255 & w1 * c1.b + w2 * c2.b + 0.5;
      c1.a = p * c1.a + (1 - p) * c2.a;
      this.rgb = c1;
    }
    return this;
  }
  interpolate(color, t) {
    if (color) {
      this._rgb = interpolate(this._rgb, color._rgb, t);
    }
    return this;
  }
  clone() {
    return new Color(this.rgb);
  }
  alpha(a) {
    this._rgb.a = n2b(a);
    return this;
  }
  clearer(ratio) {
    const rgb = this._rgb;
    rgb.a *= 1 - ratio;
    return this;
  }
  greyscale() {
    const rgb = this._rgb;
    const val = round(rgb.r * 0.3 + rgb.g * 0.59 + rgb.b * 0.11);
    rgb.r = rgb.g = rgb.b = val;
    return this;
  }
  opaquer(ratio) {
    const rgb = this._rgb;
    rgb.a *= 1 + ratio;
    return this;
  }
  negate() {
    const v = this._rgb;
    v.r = 255 - v.r;
    v.g = 255 - v.g;
    v.b = 255 - v.b;
    return this;
  }
  lighten(ratio) {
    modHSL(this._rgb, 2, ratio);
    return this;
  }
  darken(ratio) {
    modHSL(this._rgb, 2, -ratio);
    return this;
  }
  saturate(ratio) {
    modHSL(this._rgb, 1, ratio);
    return this;
  }
  desaturate(ratio) {
    modHSL(this._rgb, 1, -ratio);
    return this;
  }
  rotate(deg) {
    rotate(this._rgb, deg);
    return this;
  }
}
export { Color as C };