/*! @license DOMPurify 3.2.6 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.2.6/LICENSE */
const {
  entries,
  setPrototypeOf,
  isFrozen,
  getPrototypeOf,
  getOwnPropertyDescriptor
} = Object;
let {
  freeze,
  seal,
  create
} = Object;
let {
  apply,
  construct
} = typeof Reflect !== `\u0075\u006e\u0064\u0065\u0066\u0069\u006e\u0065\u0064` && Reflect;
if (!freeze) {
  freeze = function freeze2(x) {
    return x;
  };
}
if (!seal) {
  seal = function seal2(x) {
    return x;
  };
}
if (!apply) {
  apply = function apply2(fun, thisValue, args) {
    return fun.apply(thisValue, args);
  };
}
if (!construct) {
  construct = function construct2(Func, args) {
    return new Func(...args);
  };
}
const arrayForEach = unapply(Array.prototype.forEach);
const arrayLastIndexOf = unapply(Array.prototype.lastIndexOf);
const arrayPop = unapply(Array.prototype.pop);
const arrayPush = unapply(Array.prototype.push);
const arraySplice = unapply(Array.prototype.splice);
const stringToLowerCase = unapply(String.prototype.toLowerCase);
const stringToString = unapply(String.prototype.toString);
const stringMatch = unapply(String.prototype.match);
const stringReplace = unapply(String.prototype.replace);
const stringIndexOf = unapply(String.prototype.indexOf);
const stringTrim = unapply(String.prototype.trim);
const objectHasOwnProperty = unapply(Object.prototype.hasOwnProperty);
const regExpTest = unapply(RegExp.prototype.test);
const typeErrorCreate = unconstruct(TypeError);
function unapply(func) {
  return function (thisArg) {
    if (thisArg instanceof RegExp) {
      thisArg.lastIndex = 0;
    }
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }
    return apply(func, thisArg, args);
  };
}
function unconstruct(func) {
  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }
    return construct(func, args);
  };
}
function addToSet(set, array) {
  let transformCaseFunc = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : stringToLowerCase;
  if (setPrototypeOf) {
    setPrototypeOf(set, null);
  }
  let l = array.length;
  while (l--) {
    let element = array[l];
    if (typeof element === `\u0073\u0074\u0072\u0069\u006e\u0067`) {
      const lcElement = transformCaseFunc(element);
      if (lcElement !== element) {
        if (!isFrozen(array)) {
          array[l] = lcElement;
        }
        element = lcElement;
      }
    }
    set[element] = true;
  }
  return set;
}
function cleanArray(array) {
  for (let index = 0; index < array.length; index++) {
    const isPropertyExist = objectHasOwnProperty(array, index);
    if (!isPropertyExist) {
      array[index] = null;
    }
  }
  return array;
}
function clone(object) {
  const newObject = create(null);
  for (const [property, value] of entries(object)) {
    const isPropertyExist = objectHasOwnProperty(object, property);
    if (isPropertyExist) {
      if (Array.isArray(value)) {
        newObject[property] = cleanArray(value);
      } else if (value && typeof value === `\u006f\u0062\u006a\u0065\u0063\u0074` && value.constructor === Object) {
        newObject[property] = clone(value);
      } else {
        newObject[property] = value;
      }
    }
  }
  return newObject;
}
function lookupGetter(object, prop) {
  while (object !== null) {
    const desc = getOwnPropertyDescriptor(object, prop);
    if (desc) {
      if (desc.get) {
        return unapply(desc.get);
      }
      if (typeof desc.value === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
        return unapply(desc.value);
      }
    }
    object = getPrototypeOf(object);
  }
  function fallbackValue() {
    return null;
  }
  return fallbackValue;
}
const html$1 = freeze([`\u0061`, `\u0061\u0062\u0062\u0072`, `\u0061\u0063\u0072\u006f\u006e\u0079\u006d`, `\u0061\u0064\u0064\u0072\u0065\u0073\u0073`, `\u0061\u0072\u0065\u0061`, `\u0061\u0072\u0074\u0069\u0063\u006c\u0065`, `\u0061\u0073\u0069\u0064\u0065`, `\u0061\u0075\u0064\u0069\u006f`, `\u0062`, `\u0062\u0064\u0069`, `\u0062\u0064\u006f`, `\u0062\u0069\u0067`, `\u0062\u006c\u0069\u006e\u006b`, `\u0062\u006c\u006f\u0063\u006b\u0071\u0075\u006f\u0074\u0065`, `\u0062\u006f\u0064\u0079`, `\u0062\u0072`, `\u0062\u0075\u0074\u0074\u006f\u006e`, `\u0063\u0061\u006e\u0076\u0061\u0073`, `\u0063\u0061\u0070\u0074\u0069\u006f\u006e`, `\u0063\u0065\u006e\u0074\u0065\u0072`, `\u0063\u0069\u0074\u0065`, `\u0063\u006f\u0064\u0065`, `\u0063\u006f\u006c`, `\u0063\u006f\u006c\u0067\u0072\u006f\u0075\u0070`, `\u0063\u006f\u006e\u0074\u0065\u006e\u0074`, `\u0064\u0061\u0074\u0061`, `\u0064\u0061\u0074\u0061\u006c\u0069\u0073\u0074`, `\u0064\u0064`, `\u0064\u0065\u0063\u006f\u0072\u0061\u0074\u006f\u0072`, `\u0064\u0065\u006c`, `\u0064\u0065\u0074\u0061\u0069\u006c\u0073`, `\u0064\u0066\u006e`, `\u0064\u0069\u0061\u006c\u006f\u0067`, `\u0064\u0069\u0072`, `\u0064\u0069\u0076`, `\u0064\u006c`, `\u0064\u0074`, `\u0065\u006c\u0065\u006d\u0065\u006e\u0074`, `\u0065\u006d`, `\u0066\u0069\u0065\u006c\u0064\u0073\u0065\u0074`, `\u0066\u0069\u0067\u0063\u0061\u0070\u0074\u0069\u006f\u006e`, `\u0066\u0069\u0067\u0075\u0072\u0065`, `\u0066\u006f\u006e\u0074`, `\u0066\u006f\u006f\u0074\u0065\u0072`, `\u0066\u006f\u0072\u006d`, `\u0068\u0031`, `\u0068\u0032`, `\u0068\u0033`, `\u0068\u0034`, `\u0068\u0035`, `\u0068\u0036`, `\u0068\u0065\u0061\u0064`, `\u0068\u0065\u0061\u0064\u0065\u0072`, `\u0068\u0067\u0072\u006f\u0075\u0070`, `\u0068\u0072`, `\u0068\u0074\u006d\u006c`, `\u0069`, `\u0069\u006d\u0067`, `\u0069\u006e\u0070\u0075\u0074`, `\u0069\u006e\u0073`, `\u006b\u0062\u0064`, `\u006c\u0061\u0062\u0065\u006c`, `\u006c\u0065\u0067\u0065\u006e\u0064`, `\u006c\u0069`, `\u006d\u0061\u0069\u006e`, `\u006d\u0061\u0070`, `\u006d\u0061\u0072\u006b`, `\u006d\u0061\u0072\u0071\u0075\u0065\u0065`, `\u006d\u0065\u006e\u0075`, `\u006d\u0065\u006e\u0075\u0069\u0074\u0065\u006d`, `\u006d\u0065\u0074\u0065\u0072`, `\u006e\u0061\u0076`, `\u006e\u006f\u0062\u0072`, `\u006f\u006c`, `\u006f\u0070\u0074\u0067\u0072\u006f\u0075\u0070`, `\u006f\u0070\u0074\u0069\u006f\u006e`, `\u006f\u0075\u0074\u0070\u0075\u0074`, `\u0070`, `\u0070\u0069\u0063\u0074\u0075\u0072\u0065`, `\u0070\u0072\u0065`, `\u0070\u0072\u006f\u0067\u0072\u0065\u0073\u0073`, `\u0071`, `\u0072\u0070`, `\u0072\u0074`, `\u0072\u0075\u0062\u0079`, `\u0073`, `\u0073\u0061\u006d\u0070`, `\u0073\u0065\u0063\u0074\u0069\u006f\u006e`, `\u0073\u0065\u006c\u0065\u0063\u0074`, `\u0073\u0068\u0061\u0064\u006f\u0077`, `\u0073\u006d\u0061\u006c\u006c`, `\u0073\u006f\u0075\u0072\u0063\u0065`, `\u0073\u0070\u0061\u0063\u0065\u0072`, `\u0073\u0070\u0061\u006e`, `\u0073\u0074\u0072\u0069\u006b\u0065`, `\u0073\u0074\u0072\u006f\u006e\u0067`, `\u0073\u0074\u0079\u006c\u0065`, `\u0073\u0075\u0062`, `\u0073\u0075\u006d\u006d\u0061\u0072\u0079`, `\u0073\u0075\u0070`, `\u0074\u0061\u0062\u006c\u0065`, `\u0074\u0062\u006f\u0064\u0079`, `\u0074\u0064`, `\u0074\u0065\u006d\u0070\u006c\u0061\u0074\u0065`, `\u0074\u0065\u0078\u0074\u0061\u0072\u0065\u0061`, `\u0074\u0066\u006f\u006f\u0074`, `\u0074\u0068`, `\u0074\u0068\u0065\u0061\u0064`, `\u0074\u0069\u006d\u0065`, `\u0074\u0072`, `\u0074\u0072\u0061\u0063\u006b`, `\u0074\u0074`, `\u0075`, `\u0075\u006c`, `\u0076\u0061\u0072`, `\u0076\u0069\u0064\u0065\u006f`, `\u0077\u0062\u0072`]);
const svg$1 = freeze([`\u0073\u0076\u0067`, `\u0061`, `\u0061\u006c\u0074\u0067\u006c\u0079\u0070\u0068`, `\u0061\u006c\u0074\u0067\u006c\u0079\u0070\u0068\u0064\u0065\u0066`, `\u0061\u006c\u0074\u0067\u006c\u0079\u0070\u0068\u0069\u0074\u0065\u006d`, `\u0061\u006e\u0069\u006d\u0061\u0074\u0065\u0063\u006f\u006c\u006f\u0072`, `\u0061\u006e\u0069\u006d\u0061\u0074\u0065\u006d\u006f\u0074\u0069\u006f\u006e`, `\u0061\u006e\u0069\u006d\u0061\u0074\u0065\u0074\u0072\u0061\u006e\u0073\u0066\u006f\u0072\u006d`, `\u0063\u0069\u0072\u0063\u006c\u0065`, `\u0063\u006c\u0069\u0070\u0070\u0061\u0074\u0068`, `\u0064\u0065\u0066\u0073`, `\u0064\u0065\u0073\u0063`, `\u0065\u006c\u006c\u0069\u0070\u0073\u0065`, `\u0066\u0069\u006c\u0074\u0065\u0072`, `\u0066\u006f\u006e\u0074`, `\u0067`, `\u0067\u006c\u0079\u0070\u0068`, `\u0067\u006c\u0079\u0070\u0068\u0072\u0065\u0066`, `\u0068\u006b\u0065\u0072\u006e`, `\u0069\u006d\u0061\u0067\u0065`, `\u006c\u0069\u006e\u0065`, `\u006c\u0069\u006e\u0065\u0061\u0072\u0067\u0072\u0061\u0064\u0069\u0065\u006e\u0074`, `\u006d\u0061\u0072\u006b\u0065\u0072`, `\u006d\u0061\u0073\u006b`, `\u006d\u0065\u0074\u0061\u0064\u0061\u0074\u0061`, `\u006d\u0070\u0061\u0074\u0068`, `\u0070\u0061\u0074\u0068`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e`, `\u0070\u006f\u006c\u0079\u0067\u006f\u006e`, `\u0070\u006f\u006c\u0079\u006c\u0069\u006e\u0065`, `\u0072\u0061\u0064\u0069\u0061\u006c\u0067\u0072\u0061\u0064\u0069\u0065\u006e\u0074`, `\u0072\u0065\u0063\u0074`, `\u0073\u0074\u006f\u0070`, `\u0073\u0074\u0079\u006c\u0065`, `\u0073\u0077\u0069\u0074\u0063\u0068`, `\u0073\u0079\u006d\u0062\u006f\u006c`, `\u0074\u0065\u0078\u0074`, `\u0074\u0065\u0078\u0074\u0070\u0061\u0074\u0068`, `\u0074\u0069\u0074\u006c\u0065`, `\u0074\u0072\u0065\u0066`, `\u0074\u0073\u0070\u0061\u006e`, `\u0076\u0069\u0065\u0077`, `\u0076\u006b\u0065\u0072\u006e`]);
const svgFilters = freeze([`\u0066\u0065\u0042\u006c\u0065\u006e\u0064`, `\u0066\u0065\u0043\u006f\u006c\u006f\u0072\u004d\u0061\u0074\u0072\u0069\u0078`, `\u0066\u0065\u0043\u006f\u006d\u0070\u006f\u006e\u0065\u006e\u0074\u0054\u0072\u0061\u006e\u0073\u0066\u0065\u0072`, `\u0066\u0065\u0043\u006f\u006d\u0070\u006f\u0073\u0069\u0074\u0065`, `\u0066\u0065\u0043\u006f\u006e\u0076\u006f\u006c\u0076\u0065\u004d\u0061\u0074\u0072\u0069\u0078`, `\u0066\u0065\u0044\u0069\u0066\u0066\u0075\u0073\u0065\u004c\u0069\u0067\u0068\u0074\u0069\u006e\u0067`, `\u0066\u0065\u0044\u0069\u0073\u0070\u006c\u0061\u0063\u0065\u006d\u0065\u006e\u0074\u004d\u0061\u0070`, `\u0066\u0065\u0044\u0069\u0073\u0074\u0061\u006e\u0074\u004c\u0069\u0067\u0068\u0074`, `\u0066\u0065\u0044\u0072\u006f\u0070\u0053\u0068\u0061\u0064\u006f\u0077`, `\u0066\u0065\u0046\u006c\u006f\u006f\u0064`, `\u0066\u0065\u0046\u0075\u006e\u0063\u0041`, `\u0066\u0065\u0046\u0075\u006e\u0063\u0042`, `\u0066\u0065\u0046\u0075\u006e\u0063\u0047`, `\u0066\u0065\u0046\u0075\u006e\u0063\u0052`, `\u0066\u0065\u0047\u0061\u0075\u0073\u0073\u0069\u0061\u006e\u0042\u006c\u0075\u0072`, `\u0066\u0065\u0049\u006d\u0061\u0067\u0065`, `\u0066\u0065\u004d\u0065\u0072\u0067\u0065`, `\u0066\u0065\u004d\u0065\u0072\u0067\u0065\u004e\u006f\u0064\u0065`, `\u0066\u0065\u004d\u006f\u0072\u0070\u0068\u006f\u006c\u006f\u0067\u0079`, `\u0066\u0065\u004f\u0066\u0066\u0073\u0065\u0074`, `\u0066\u0065\u0050\u006f\u0069\u006e\u0074\u004c\u0069\u0067\u0068\u0074`, `\u0066\u0065\u0053\u0070\u0065\u0063\u0075\u006c\u0061\u0072\u004c\u0069\u0067\u0068\u0074\u0069\u006e\u0067`, `\u0066\u0065\u0053\u0070\u006f\u0074\u004c\u0069\u0067\u0068\u0074`, `\u0066\u0065\u0054\u0069\u006c\u0065`, `\u0066\u0065\u0054\u0075\u0072\u0062\u0075\u006c\u0065\u006e\u0063\u0065`]);
const svgDisallowed = freeze([`\u0061\u006e\u0069\u006d\u0061\u0074\u0065`, `\u0063\u006f\u006c\u006f\u0072\u002d\u0070\u0072\u006f\u0066\u0069\u006c\u0065`, `\u0063\u0075\u0072\u0073\u006f\u0072`, `\u0064\u0069\u0073\u0063\u0061\u0072\u0064`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u0063\u0065`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u0063\u0065\u002d\u0066\u006f\u0072\u006d\u0061\u0074`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u0063\u0065\u002d\u006e\u0061\u006d\u0065`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u0063\u0065\u002d\u0073\u0072\u0063`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u0063\u0065\u002d\u0075\u0072\u0069`, `\u0066\u006f\u0072\u0065\u0069\u0067\u006e\u006f\u0062\u006a\u0065\u0063\u0074`, `\u0068\u0061\u0074\u0063\u0068`, `\u0068\u0061\u0074\u0063\u0068\u0070\u0061\u0074\u0068`, `\u006d\u0065\u0073\u0068`, `\u006d\u0065\u0073\u0068\u0067\u0072\u0061\u0064\u0069\u0065\u006e\u0074`, `\u006d\u0065\u0073\u0068\u0070\u0061\u0074\u0063\u0068`, `\u006d\u0065\u0073\u0068\u0072\u006f\u0077`, `\u006d\u0069\u0073\u0073\u0069\u006e\u0067\u002d\u0067\u006c\u0079\u0070\u0068`, `\u0073\u0063\u0072\u0069\u0070\u0074`, `\u0073\u0065\u0074`, `\u0073\u006f\u006c\u0069\u0064\u0063\u006f\u006c\u006f\u0072`, `\u0075\u006e\u006b\u006e\u006f\u0077\u006e`, `\u0075\u0073\u0065`]);
const mathMl$1 = freeze([`\u006d\u0061\u0074\u0068`, `\u006d\u0065\u006e\u0063\u006c\u006f\u0073\u0065`, `\u006d\u0065\u0072\u0072\u006f\u0072`, `\u006d\u0066\u0065\u006e\u0063\u0065\u0064`, `\u006d\u0066\u0072\u0061\u0063`, `\u006d\u0067\u006c\u0079\u0070\u0068`, `\u006d\u0069`, `\u006d\u006c\u0061\u0062\u0065\u006c\u0065\u0064\u0074\u0072`, `\u006d\u006d\u0075\u006c\u0074\u0069\u0073\u0063\u0072\u0069\u0070\u0074\u0073`, `\u006d\u006e`, `\u006d\u006f`, `\u006d\u006f\u0076\u0065\u0072`, `\u006d\u0070\u0061\u0064\u0064\u0065\u0064`, `\u006d\u0070\u0068\u0061\u006e\u0074\u006f\u006d`, `\u006d\u0072\u006f\u006f\u0074`, `\u006d\u0072\u006f\u0077`, `\u006d\u0073`, `\u006d\u0073\u0070\u0061\u0063\u0065`, `\u006d\u0073\u0071\u0072\u0074`, `\u006d\u0073\u0074\u0079\u006c\u0065`, `\u006d\u0073\u0075\u0062`, `\u006d\u0073\u0075\u0070`, `\u006d\u0073\u0075\u0062\u0073\u0075\u0070`, `\u006d\u0074\u0061\u0062\u006c\u0065`, `\u006d\u0074\u0064`, `\u006d\u0074\u0065\u0078\u0074`, `\u006d\u0074\u0072`, `\u006d\u0075\u006e\u0064\u0065\u0072`, `\u006d\u0075\u006e\u0064\u0065\u0072\u006f\u0076\u0065\u0072`, `\u006d\u0070\u0072\u0065\u0073\u0063\u0072\u0069\u0070\u0074\u0073`]);
const mathMlDisallowed = freeze([`\u006d\u0061\u0063\u0074\u0069\u006f\u006e`, `\u006d\u0061\u006c\u0069\u0067\u006e\u0067\u0072\u006f\u0075\u0070`, `\u006d\u0061\u006c\u0069\u0067\u006e\u006d\u0061\u0072\u006b`, `\u006d\u006c\u006f\u006e\u0067\u0064\u0069\u0076`, `\u006d\u0073\u0063\u0061\u0072\u0072\u0069\u0065\u0073`, `\u006d\u0073\u0063\u0061\u0072\u0072\u0079`, `\u006d\u0073\u0067\u0072\u006f\u0075\u0070`, `\u006d\u0073\u0074\u0061\u0063\u006b`, `\u006d\u0073\u006c\u0069\u006e\u0065`, `\u006d\u0073\u0072\u006f\u0077`, `\u0073\u0065\u006d\u0061\u006e\u0074\u0069\u0063\u0073`, `\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e`, `\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e\u002d\u0078\u006d\u006c`, `\u006d\u0070\u0072\u0065\u0073\u0063\u0072\u0069\u0070\u0074\u0073`, `\u006e\u006f\u006e\u0065`]);
const text = freeze([`\u0023\u0074\u0065\u0078\u0074`]);
const html = freeze([`\u0061\u0063\u0063\u0065\u0070\u0074`, `\u0061\u0063\u0074\u0069\u006f\u006e`, `\u0061\u006c\u0069\u0067\u006e`, `\u0061\u006c\u0074`, `\u0061\u0075\u0074\u006f\u0063\u0061\u0070\u0069\u0074\u0061\u006c\u0069\u007a\u0065`, `\u0061\u0075\u0074\u006f\u0063\u006f\u006d\u0070\u006c\u0065\u0074\u0065`, `\u0061\u0075\u0074\u006f\u0070\u0069\u0063\u0074\u0075\u0072\u0065\u0069\u006e\u0070\u0069\u0063\u0074\u0075\u0072\u0065`, `\u0061\u0075\u0074\u006f\u0070\u006c\u0061\u0079`, `\u0062\u0061\u0063\u006b\u0067\u0072\u006f\u0075\u006e\u0064`, `\u0062\u0067\u0063\u006f\u006c\u006f\u0072`, `\u0062\u006f\u0072\u0064\u0065\u0072`, `\u0063\u0061\u0070\u0074\u0075\u0072\u0065`, `\u0063\u0065\u006c\u006c\u0070\u0061\u0064\u0064\u0069\u006e\u0067`, `\u0063\u0065\u006c\u006c\u0073\u0070\u0061\u0063\u0069\u006e\u0067`, `\u0063\u0068\u0065\u0063\u006b\u0065\u0064`, `\u0063\u0069\u0074\u0065`, `\u0063\u006c\u0061\u0073\u0073`, `\u0063\u006c\u0065\u0061\u0072`, `\u0063\u006f\u006c\u006f\u0072`, `\u0063\u006f\u006c\u0073`, `\u0063\u006f\u006c\u0073\u0070\u0061\u006e`, `\u0063\u006f\u006e\u0074\u0072\u006f\u006c\u0073`, `\u0063\u006f\u006e\u0074\u0072\u006f\u006c\u0073\u006c\u0069\u0073\u0074`, `\u0063\u006f\u006f\u0072\u0064\u0073`, `\u0063\u0072\u006f\u0073\u0073\u006f\u0072\u0069\u0067\u0069\u006e`, `\u0064\u0061\u0074\u0065\u0074\u0069\u006d\u0065`, `\u0064\u0065\u0063\u006f\u0064\u0069\u006e\u0067`, `\u0064\u0065\u0066\u0061\u0075\u006c\u0074`, `\u0064\u0069\u0072`, `\u0064\u0069\u0073\u0061\u0062\u006c\u0065\u0064`, `\u0064\u0069\u0073\u0061\u0062\u006c\u0065\u0070\u0069\u0063\u0074\u0075\u0072\u0065\u0069\u006e\u0070\u0069\u0063\u0074\u0075\u0072\u0065`, `\u0064\u0069\u0073\u0061\u0062\u006c\u0065\u0072\u0065\u006d\u006f\u0074\u0065\u0070\u006c\u0061\u0079\u0062\u0061\u0063\u006b`, `\u0064\u006f\u0077\u006e\u006c\u006f\u0061\u0064`, `\u0064\u0072\u0061\u0067\u0067\u0061\u0062\u006c\u0065`, `\u0065\u006e\u0063\u0074\u0079\u0070\u0065`, `\u0065\u006e\u0074\u0065\u0072\u006b\u0065\u0079\u0068\u0069\u006e\u0074`, `\u0066\u0061\u0063\u0065`, `\u0066\u006f\u0072`, `\u0068\u0065\u0061\u0064\u0065\u0072\u0073`, `\u0068\u0065\u0069\u0067\u0068\u0074`, `\u0068\u0069\u0064\u0064\u0065\u006e`, `\u0068\u0069\u0067\u0068`, `\u0068\u0072\u0065\u0066`, `\u0068\u0072\u0065\u0066\u006c\u0061\u006e\u0067`, `\u0069\u0064`, `\u0069\u006e\u0070\u0075\u0074\u006d\u006f\u0064\u0065`, `\u0069\u006e\u0074\u0065\u0067\u0072\u0069\u0074\u0079`, `\u0069\u0073\u006d\u0061\u0070`, `\u006b\u0069\u006e\u0064`, `\u006c\u0061\u0062\u0065\u006c`, `\u006c\u0061\u006e\u0067`, `\u006c\u0069\u0073\u0074`, `\u006c\u006f\u0061\u0064\u0069\u006e\u0067`, `\u006c\u006f\u006f\u0070`, `\u006c\u006f\u0077`, `\u006d\u0061\u0078`, `\u006d\u0061\u0078\u006c\u0065\u006e\u0067\u0074\u0068`, `\u006d\u0065\u0064\u0069\u0061`, `\u006d\u0065\u0074\u0068\u006f\u0064`, `\u006d\u0069\u006e`, `\u006d\u0069\u006e\u006c\u0065\u006e\u0067\u0074\u0068`, `\u006d\u0075\u006c\u0074\u0069\u0070\u006c\u0065`, `\u006d\u0075\u0074\u0065\u0064`, `\u006e\u0061\u006d\u0065`, `\u006e\u006f\u006e\u0063\u0065`, `\u006e\u006f\u0073\u0068\u0061\u0064\u0065`, `\u006e\u006f\u0076\u0061\u006c\u0069\u0064\u0061\u0074\u0065`, `\u006e\u006f\u0077\u0072\u0061\u0070`, `\u006f\u0070\u0065\u006e`, `\u006f\u0070\u0074\u0069\u006d\u0075\u006d`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e`, `\u0070\u006c\u0061\u0063\u0065\u0068\u006f\u006c\u0064\u0065\u0072`, `\u0070\u006c\u0061\u0079\u0073\u0069\u006e\u006c\u0069\u006e\u0065`, `\u0070\u006f\u0070\u006f\u0076\u0065\u0072`, `\u0070\u006f\u0070\u006f\u0076\u0065\u0072\u0074\u0061\u0072\u0067\u0065\u0074`, `\u0070\u006f\u0070\u006f\u0076\u0065\u0072\u0074\u0061\u0072\u0067\u0065\u0074\u0061\u0063\u0074\u0069\u006f\u006e`, `\u0070\u006f\u0073\u0074\u0065\u0072`, `\u0070\u0072\u0065\u006c\u006f\u0061\u0064`, `\u0070\u0075\u0062\u0064\u0061\u0074\u0065`, `\u0072\u0061\u0064\u0069\u006f\u0067\u0072\u006f\u0075\u0070`, `\u0072\u0065\u0061\u0064\u006f\u006e\u006c\u0079`, `\u0072\u0065\u006c`, `\u0072\u0065\u0071\u0075\u0069\u0072\u0065\u0064`, `\u0072\u0065\u0076`, `\u0072\u0065\u0076\u0065\u0072\u0073\u0065\u0064`, `\u0072\u006f\u006c\u0065`, `\u0072\u006f\u0077\u0073`, `\u0072\u006f\u0077\u0073\u0070\u0061\u006e`, `\u0073\u0070\u0065\u006c\u006c\u0063\u0068\u0065\u0063\u006b`, `\u0073\u0063\u006f\u0070\u0065`, `\u0073\u0065\u006c\u0065\u0063\u0074\u0065\u0064`, `\u0073\u0068\u0061\u0070\u0065`, `\u0073\u0069\u007a\u0065`, `\u0073\u0069\u007a\u0065\u0073`, `\u0073\u0070\u0061\u006e`, `\u0073\u0072\u0063\u006c\u0061\u006e\u0067`, `\u0073\u0074\u0061\u0072\u0074`, `\u0073\u0072\u0063`, `\u0073\u0072\u0063\u0073\u0065\u0074`, `\u0073\u0074\u0065\u0070`, `\u0073\u0074\u0079\u006c\u0065`, `\u0073\u0075\u006d\u006d\u0061\u0072\u0079`, `\u0074\u0061\u0062\u0069\u006e\u0064\u0065\u0078`, `\u0074\u0069\u0074\u006c\u0065`, `\u0074\u0072\u0061\u006e\u0073\u006c\u0061\u0074\u0065`, `\u0074\u0079\u0070\u0065`, `\u0075\u0073\u0065\u006d\u0061\u0070`, `\u0076\u0061\u006c\u0069\u0067\u006e`, `\u0076\u0061\u006c\u0075\u0065`, `\u0077\u0069\u0064\u0074\u0068`, `\u0077\u0072\u0061\u0070`, `\u0078\u006d\u006c\u006e\u0073`, `\u0073\u006c\u006f\u0074`]);
const svg = freeze([`\u0061\u0063\u0063\u0065\u006e\u0074\u002d\u0068\u0065\u0069\u0067\u0068\u0074`, `\u0061\u0063\u0063\u0075\u006d\u0075\u006c\u0061\u0074\u0065`, `\u0061\u0064\u0064\u0069\u0074\u0069\u0076\u0065`, `\u0061\u006c\u0069\u0067\u006e\u006d\u0065\u006e\u0074\u002d\u0062\u0061\u0073\u0065\u006c\u0069\u006e\u0065`, `\u0061\u006d\u0070\u006c\u0069\u0074\u0075\u0064\u0065`, `\u0061\u0073\u0063\u0065\u006e\u0074`, `\u0061\u0074\u0074\u0072\u0069\u0062\u0075\u0074\u0065\u006e\u0061\u006d\u0065`, `\u0061\u0074\u0074\u0072\u0069\u0062\u0075\u0074\u0065\u0074\u0079\u0070\u0065`, `\u0061\u007a\u0069\u006d\u0075\u0074\u0068`, `\u0062\u0061\u0073\u0065\u0066\u0072\u0065\u0071\u0075\u0065\u006e\u0063\u0079`, `\u0062\u0061\u0073\u0065\u006c\u0069\u006e\u0065\u002d\u0073\u0068\u0069\u0066\u0074`, `\u0062\u0065\u0067\u0069\u006e`, `\u0062\u0069\u0061\u0073`, `\u0062\u0079`, `\u0063\u006c\u0061\u0073\u0073`, `\u0063\u006c\u0069\u0070`, `\u0063\u006c\u0069\u0070\u0070\u0061\u0074\u0068\u0075\u006e\u0069\u0074\u0073`, `\u0063\u006c\u0069\u0070\u002d\u0070\u0061\u0074\u0068`, `\u0063\u006c\u0069\u0070\u002d\u0072\u0075\u006c\u0065`, `\u0063\u006f\u006c\u006f\u0072`, `\u0063\u006f\u006c\u006f\u0072\u002d\u0069\u006e\u0074\u0065\u0072\u0070\u006f\u006c\u0061\u0074\u0069\u006f\u006e`, `\u0063\u006f\u006c\u006f\u0072\u002d\u0069\u006e\u0074\u0065\u0072\u0070\u006f\u006c\u0061\u0074\u0069\u006f\u006e\u002d\u0066\u0069\u006c\u0074\u0065\u0072\u0073`, `\u0063\u006f\u006c\u006f\u0072\u002d\u0070\u0072\u006f\u0066\u0069\u006c\u0065`, `\u0063\u006f\u006c\u006f\u0072\u002d\u0072\u0065\u006e\u0064\u0065\u0072\u0069\u006e\u0067`, `\u0063\u0078`, `\u0063\u0079`, `\u0064`, `\u0064\u0078`, `\u0064\u0079`, `\u0064\u0069\u0066\u0066\u0075\u0073\u0065\u0063\u006f\u006e\u0073\u0074\u0061\u006e\u0074`, `\u0064\u0069\u0072\u0065\u0063\u0074\u0069\u006f\u006e`, `\u0064\u0069\u0073\u0070\u006c\u0061\u0079`, `\u0064\u0069\u0076\u0069\u0073\u006f\u0072`, `\u0064\u0075\u0072`, `\u0065\u0064\u0067\u0065\u006d\u006f\u0064\u0065`, `\u0065\u006c\u0065\u0076\u0061\u0074\u0069\u006f\u006e`, `\u0065\u006e\u0064`, `\u0065\u0078\u0070\u006f\u006e\u0065\u006e\u0074`, `\u0066\u0069\u006c\u006c`, `\u0066\u0069\u006c\u006c\u002d\u006f\u0070\u0061\u0063\u0069\u0074\u0079`, `\u0066\u0069\u006c\u006c\u002d\u0072\u0075\u006c\u0065`, `\u0066\u0069\u006c\u0074\u0065\u0072`, `\u0066\u0069\u006c\u0074\u0065\u0072\u0075\u006e\u0069\u0074\u0073`, `\u0066\u006c\u006f\u006f\u0064\u002d\u0063\u006f\u006c\u006f\u0072`, `\u0066\u006c\u006f\u006f\u0064\u002d\u006f\u0070\u0061\u0063\u0069\u0074\u0079`, `\u0066\u006f\u006e\u0074\u002d\u0066\u0061\u006d\u0069\u006c\u0079`, `\u0066\u006f\u006e\u0074\u002d\u0073\u0069\u007a\u0065`, `\u0066\u006f\u006e\u0074\u002d\u0073\u0069\u007a\u0065\u002d\u0061\u0064\u006a\u0075\u0073\u0074`, `\u0066\u006f\u006e\u0074\u002d\u0073\u0074\u0072\u0065\u0074\u0063\u0068`, `\u0066\u006f\u006e\u0074\u002d\u0073\u0074\u0079\u006c\u0065`, `\u0066\u006f\u006e\u0074\u002d\u0076\u0061\u0072\u0069\u0061\u006e\u0074`, `\u0066\u006f\u006e\u0074\u002d\u0077\u0065\u0069\u0067\u0068\u0074`, `\u0066\u0078`, `\u0066\u0079`, `\u0067\u0031`, `\u0067\u0032`, `\u0067\u006c\u0079\u0070\u0068\u002d\u006e\u0061\u006d\u0065`, `\u0067\u006c\u0079\u0070\u0068\u0072\u0065\u0066`, `\u0067\u0072\u0061\u0064\u0069\u0065\u006e\u0074\u0075\u006e\u0069\u0074\u0073`, `\u0067\u0072\u0061\u0064\u0069\u0065\u006e\u0074\u0074\u0072\u0061\u006e\u0073\u0066\u006f\u0072\u006d`, `\u0068\u0065\u0069\u0067\u0068\u0074`, `\u0068\u0072\u0065\u0066`, `\u0069\u0064`, `\u0069\u006d\u0061\u0067\u0065\u002d\u0072\u0065\u006e\u0064\u0065\u0072\u0069\u006e\u0067`, `\u0069\u006e`, `\u0069\u006e\u0032`, `\u0069\u006e\u0074\u0065\u0072\u0063\u0065\u0070\u0074`, `\u006b`, `\u006b\u0031`, `\u006b\u0032`, `\u006b\u0033`, `\u006b\u0034`, `\u006b\u0065\u0072\u006e\u0069\u006e\u0067`, `\u006b\u0065\u0079\u0070\u006f\u0069\u006e\u0074\u0073`, `\u006b\u0065\u0079\u0073\u0070\u006c\u0069\u006e\u0065\u0073`, `\u006b\u0065\u0079\u0074\u0069\u006d\u0065\u0073`, `\u006c\u0061\u006e\u0067`, `\u006c\u0065\u006e\u0067\u0074\u0068\u0061\u0064\u006a\u0075\u0073\u0074`, `\u006c\u0065\u0074\u0074\u0065\u0072\u002d\u0073\u0070\u0061\u0063\u0069\u006e\u0067`, `\u006b\u0065\u0072\u006e\u0065\u006c\u006d\u0061\u0074\u0072\u0069\u0078`, `\u006b\u0065\u0072\u006e\u0065\u006c\u0075\u006e\u0069\u0074\u006c\u0065\u006e\u0067\u0074\u0068`, `\u006c\u0069\u0067\u0068\u0074\u0069\u006e\u0067\u002d\u0063\u006f\u006c\u006f\u0072`, `\u006c\u006f\u0063\u0061\u006c`, `\u006d\u0061\u0072\u006b\u0065\u0072\u002d\u0065\u006e\u0064`, `\u006d\u0061\u0072\u006b\u0065\u0072\u002d\u006d\u0069\u0064`, `\u006d\u0061\u0072\u006b\u0065\u0072\u002d\u0073\u0074\u0061\u0072\u0074`, `\u006d\u0061\u0072\u006b\u0065\u0072\u0068\u0065\u0069\u0067\u0068\u0074`, `\u006d\u0061\u0072\u006b\u0065\u0072\u0075\u006e\u0069\u0074\u0073`, `\u006d\u0061\u0072\u006b\u0065\u0072\u0077\u0069\u0064\u0074\u0068`, `\u006d\u0061\u0073\u006b\u0063\u006f\u006e\u0074\u0065\u006e\u0074\u0075\u006e\u0069\u0074\u0073`, `\u006d\u0061\u0073\u006b\u0075\u006e\u0069\u0074\u0073`, `\u006d\u0061\u0078`, `\u006d\u0061\u0073\u006b`, `\u006d\u0065\u0064\u0069\u0061`, `\u006d\u0065\u0074\u0068\u006f\u0064`, `\u006d\u006f\u0064\u0065`, `\u006d\u0069\u006e`, `\u006e\u0061\u006d\u0065`, `\u006e\u0075\u006d\u006f\u0063\u0074\u0061\u0076\u0065\u0073`, `\u006f\u0066\u0066\u0073\u0065\u0074`, `\u006f\u0070\u0065\u0072\u0061\u0074\u006f\u0072`, `\u006f\u0070\u0061\u0063\u0069\u0074\u0079`, `\u006f\u0072\u0064\u0065\u0072`, `\u006f\u0072\u0069\u0065\u006e\u0074`, `\u006f\u0072\u0069\u0065\u006e\u0074\u0061\u0074\u0069\u006f\u006e`, `\u006f\u0072\u0069\u0067\u0069\u006e`, `\u006f\u0076\u0065\u0072\u0066\u006c\u006f\u0077`, `\u0070\u0061\u0069\u006e\u0074\u002d\u006f\u0072\u0064\u0065\u0072`, `\u0070\u0061\u0074\u0068`, `\u0070\u0061\u0074\u0068\u006c\u0065\u006e\u0067\u0074\u0068`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e\u0063\u006f\u006e\u0074\u0065\u006e\u0074\u0075\u006e\u0069\u0074\u0073`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e\u0074\u0072\u0061\u006e\u0073\u0066\u006f\u0072\u006d`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e\u0075\u006e\u0069\u0074\u0073`, `\u0070\u006f\u0069\u006e\u0074\u0073`, `\u0070\u0072\u0065\u0073\u0065\u0072\u0076\u0065\u0061\u006c\u0070\u0068\u0061`, `\u0070\u0072\u0065\u0073\u0065\u0072\u0076\u0065\u0061\u0073\u0070\u0065\u0063\u0074\u0072\u0061\u0074\u0069\u006f`, `\u0070\u0072\u0069\u006d\u0069\u0074\u0069\u0076\u0065\u0075\u006e\u0069\u0074\u0073`, `\u0072`, `\u0072\u0078`, `\u0072\u0079`, `\u0072\u0061\u0064\u0069\u0075\u0073`, `\u0072\u0065\u0066\u0078`, `\u0072\u0065\u0066\u0079`, `\u0072\u0065\u0070\u0065\u0061\u0074\u0063\u006f\u0075\u006e\u0074`, `\u0072\u0065\u0070\u0065\u0061\u0074\u0064\u0075\u0072`, `\u0072\u0065\u0073\u0074\u0061\u0072\u0074`, `\u0072\u0065\u0073\u0075\u006c\u0074`, `\u0072\u006f\u0074\u0061\u0074\u0065`, `\u0073\u0063\u0061\u006c\u0065`, `\u0073\u0065\u0065\u0064`, `\u0073\u0068\u0061\u0070\u0065\u002d\u0072\u0065\u006e\u0064\u0065\u0072\u0069\u006e\u0067`, `\u0073\u006c\u006f\u0070\u0065`, `\u0073\u0070\u0065\u0063\u0075\u006c\u0061\u0072\u0063\u006f\u006e\u0073\u0074\u0061\u006e\u0074`, `\u0073\u0070\u0065\u0063\u0075\u006c\u0061\u0072\u0065\u0078\u0070\u006f\u006e\u0065\u006e\u0074`, `\u0073\u0070\u0072\u0065\u0061\u0064\u006d\u0065\u0074\u0068\u006f\u0064`, `\u0073\u0074\u0061\u0072\u0074\u006f\u0066\u0066\u0073\u0065\u0074`, `\u0073\u0074\u0064\u0064\u0065\u0076\u0069\u0061\u0074\u0069\u006f\u006e`, `\u0073\u0074\u0069\u0074\u0063\u0068\u0074\u0069\u006c\u0065\u0073`, `\u0073\u0074\u006f\u0070\u002d\u0063\u006f\u006c\u006f\u0072`, `\u0073\u0074\u006f\u0070\u002d\u006f\u0070\u0061\u0063\u0069\u0074\u0079`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u0064\u0061\u0073\u0068\u0061\u0072\u0072\u0061\u0079`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u0064\u0061\u0073\u0068\u006f\u0066\u0066\u0073\u0065\u0074`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u006c\u0069\u006e\u0065\u0063\u0061\u0070`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u006c\u0069\u006e\u0065\u006a\u006f\u0069\u006e`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u006d\u0069\u0074\u0065\u0072\u006c\u0069\u006d\u0069\u0074`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u006f\u0070\u0061\u0063\u0069\u0074\u0079`, `\u0073\u0074\u0072\u006f\u006b\u0065`, `\u0073\u0074\u0072\u006f\u006b\u0065\u002d\u0077\u0069\u0064\u0074\u0068`, `\u0073\u0074\u0079\u006c\u0065`, `\u0073\u0075\u0072\u0066\u0061\u0063\u0065\u0073\u0063\u0061\u006c\u0065`, `\u0073\u0079\u0073\u0074\u0065\u006d\u006c\u0061\u006e\u0067\u0075\u0061\u0067\u0065`, `\u0074\u0061\u0062\u0069\u006e\u0064\u0065\u0078`, `\u0074\u0061\u0062\u006c\u0065\u0076\u0061\u006c\u0075\u0065\u0073`, `\u0074\u0061\u0072\u0067\u0065\u0074\u0078`, `\u0074\u0061\u0072\u0067\u0065\u0074\u0079`, `\u0074\u0072\u0061\u006e\u0073\u0066\u006f\u0072\u006d`, `\u0074\u0072\u0061\u006e\u0073\u0066\u006f\u0072\u006d\u002d\u006f\u0072\u0069\u0067\u0069\u006e`, `\u0074\u0065\u0078\u0074\u002d\u0061\u006e\u0063\u0068\u006f\u0072`, `\u0074\u0065\u0078\u0074\u002d\u0064\u0065\u0063\u006f\u0072\u0061\u0074\u0069\u006f\u006e`, `\u0074\u0065\u0078\u0074\u002d\u0072\u0065\u006e\u0064\u0065\u0072\u0069\u006e\u0067`, `\u0074\u0065\u0078\u0074\u006c\u0065\u006e\u0067\u0074\u0068`, `\u0074\u0079\u0070\u0065`, `\u0075\u0031`, `\u0075\u0032`, `\u0075\u006e\u0069\u0063\u006f\u0064\u0065`, `\u0076\u0061\u006c\u0075\u0065\u0073`, `\u0076\u0069\u0065\u0077\u0062\u006f\u0078`, `\u0076\u0069\u0073\u0069\u0062\u0069\u006c\u0069\u0074\u0079`, `\u0076\u0065\u0072\u0073\u0069\u006f\u006e`, `\u0076\u0065\u0072\u0074\u002d\u0061\u0064\u0076\u002d\u0079`, `\u0076\u0065\u0072\u0074\u002d\u006f\u0072\u0069\u0067\u0069\u006e\u002d\u0078`, `\u0076\u0065\u0072\u0074\u002d\u006f\u0072\u0069\u0067\u0069\u006e\u002d\u0079`, `\u0077\u0069\u0064\u0074\u0068`, `\u0077\u006f\u0072\u0064\u002d\u0073\u0070\u0061\u0063\u0069\u006e\u0067`, `\u0077\u0072\u0061\u0070`, `\u0077\u0072\u0069\u0074\u0069\u006e\u0067\u002d\u006d\u006f\u0064\u0065`, `\u0078\u0063\u0068\u0061\u006e\u006e\u0065\u006c\u0073\u0065\u006c\u0065\u0063\u0074\u006f\u0072`, `\u0079\u0063\u0068\u0061\u006e\u006e\u0065\u006c\u0073\u0065\u006c\u0065\u0063\u0074\u006f\u0072`, `\u0078`, `\u0078\u0031`, `\u0078\u0032`, `\u0078\u006d\u006c\u006e\u0073`, `\u0079`, `\u0079\u0031`, `\u0079\u0032`, `\u007a`, `\u007a\u006f\u006f\u006d\u0061\u006e\u0064\u0070\u0061\u006e`]);
const mathMl = freeze([`\u0061\u0063\u0063\u0065\u006e\u0074`, `\u0061\u0063\u0063\u0065\u006e\u0074\u0075\u006e\u0064\u0065\u0072`, `\u0061\u006c\u0069\u0067\u006e`, `\u0062\u0065\u0076\u0065\u006c\u006c\u0065\u0064`, `\u0063\u006c\u006f\u0073\u0065`, `\u0063\u006f\u006c\u0075\u006d\u006e\u0073\u0061\u006c\u0069\u0067\u006e`, `\u0063\u006f\u006c\u0075\u006d\u006e\u006c\u0069\u006e\u0065\u0073`, `\u0063\u006f\u006c\u0075\u006d\u006e\u0073\u0070\u0061\u006e`, `\u0064\u0065\u006e\u006f\u006d\u0061\u006c\u0069\u0067\u006e`, `\u0064\u0065\u0070\u0074\u0068`, `\u0064\u0069\u0072`, `\u0064\u0069\u0073\u0070\u006c\u0061\u0079`, `\u0064\u0069\u0073\u0070\u006c\u0061\u0079\u0073\u0074\u0079\u006c\u0065`, `\u0065\u006e\u0063\u006f\u0064\u0069\u006e\u0067`, `\u0066\u0065\u006e\u0063\u0065`, `\u0066\u0072\u0061\u006d\u0065`, `\u0068\u0065\u0069\u0067\u0068\u0074`, `\u0068\u0072\u0065\u0066`, `\u0069\u0064`, `\u006c\u0061\u0072\u0067\u0065\u006f\u0070`, `\u006c\u0065\u006e\u0067\u0074\u0068`, `\u006c\u0069\u006e\u0065\u0074\u0068\u0069\u0063\u006b\u006e\u0065\u0073\u0073`, `\u006c\u0073\u0070\u0061\u0063\u0065`, `\u006c\u0071\u0075\u006f\u0074\u0065`, `\u006d\u0061\u0074\u0068\u0062\u0061\u0063\u006b\u0067\u0072\u006f\u0075\u006e\u0064`, `\u006d\u0061\u0074\u0068\u0063\u006f\u006c\u006f\u0072`, `\u006d\u0061\u0074\u0068\u0073\u0069\u007a\u0065`, `\u006d\u0061\u0074\u0068\u0076\u0061\u0072\u0069\u0061\u006e\u0074`, `\u006d\u0061\u0078\u0073\u0069\u007a\u0065`, `\u006d\u0069\u006e\u0073\u0069\u007a\u0065`, `\u006d\u006f\u0076\u0061\u0062\u006c\u0065\u006c\u0069\u006d\u0069\u0074\u0073`, `\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e`, `\u006e\u0075\u006d\u0061\u006c\u0069\u0067\u006e`, `\u006f\u0070\u0065\u006e`, `\u0072\u006f\u0077\u0061\u006c\u0069\u0067\u006e`, `\u0072\u006f\u0077\u006c\u0069\u006e\u0065\u0073`, `\u0072\u006f\u0077\u0073\u0070\u0061\u0063\u0069\u006e\u0067`, `\u0072\u006f\u0077\u0073\u0070\u0061\u006e`, `\u0072\u0073\u0070\u0061\u0063\u0065`, `\u0072\u0071\u0075\u006f\u0074\u0065`, `\u0073\u0063\u0072\u0069\u0070\u0074\u006c\u0065\u0076\u0065\u006c`, `\u0073\u0063\u0072\u0069\u0070\u0074\u006d\u0069\u006e\u0073\u0069\u007a\u0065`, `\u0073\u0063\u0072\u0069\u0070\u0074\u0073\u0069\u007a\u0065\u006d\u0075\u006c\u0074\u0069\u0070\u006c\u0069\u0065\u0072`, `\u0073\u0065\u006c\u0065\u0063\u0074\u0069\u006f\u006e`, `\u0073\u0065\u0070\u0061\u0072\u0061\u0074\u006f\u0072`, `\u0073\u0065\u0070\u0061\u0072\u0061\u0074\u006f\u0072\u0073`, `\u0073\u0074\u0072\u0065\u0074\u0063\u0068\u0079`, `\u0073\u0075\u0062\u0073\u0063\u0072\u0069\u0070\u0074\u0073\u0068\u0069\u0066\u0074`, `\u0073\u0075\u0070\u0073\u0063\u0072\u0069\u0070\u0074\u0073\u0068\u0069\u0066\u0074`, `\u0073\u0079\u006d\u006d\u0065\u0074\u0072\u0069\u0063`, `\u0076\u006f\u0066\u0066\u0073\u0065\u0074`, `\u0077\u0069\u0064\u0074\u0068`, `\u0078\u006d\u006c\u006e\u0073`]);
const xml = freeze([`\u0078\u006c\u0069\u006e\u006b\u003a\u0068\u0072\u0065\u0066`, `\u0078\u006d\u006c\u003a\u0069\u0064`, `\u0078\u006c\u0069\u006e\u006b\u003a\u0074\u0069\u0074\u006c\u0065`, `\u0078\u006d\u006c\u003a\u0073\u0070\u0061\u0063\u0065`, `\u0078\u006d\u006c\u006e\u0073\u003a\u0078\u006c\u0069\u006e\u006b`]);
const MUSTACHE_EXPR = seal(/\{\{[\w\W]*|[\w\W]*\}\}/gm);
const ERB_EXPR = seal(/<%[\w\W]*|[\w\W]*%>/gm);
const TMPLIT_EXPR = seal(/\$\{[\w\W]*/gm);
const DATA_ATTR = seal(/^data-[\-\w.\u00B7-\uFFFF]+$/);
const ARIA_ATTR = seal(/^aria-[\-\w]+$/);
const IS_ALLOWED_URI = seal(/^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp|matrix):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i
// eslint-disable-line no-useless-escape
);
const IS_SCRIPT_OR_DATA = seal(/^(?:\w+script|data):/i);
const ATTR_WHITESPACE = seal(/[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g
// eslint-disable-line no-control-regex
);
const DOCTYPE_NAME = seal(/^html$/i);
const CUSTOM_ELEMENT = seal(/^[a-z][.\w]*(-[.\w]+)+$/i);
var EXPRESSIONS = /* @__PURE__ */Object.freeze({
  __proto__: null,
  ARIA_ATTR,
  ATTR_WHITESPACE,
  CUSTOM_ELEMENT,
  DATA_ATTR,
  DOCTYPE_NAME,
  ERB_EXPR,
  IS_ALLOWED_URI,
  IS_SCRIPT_OR_DATA,
  MUSTACHE_EXPR,
  TMPLIT_EXPR
});
const NODE_TYPE = {
  element: 1,
  text: 3,
  // Deprecated
  progressingInstruction: 7,
  comment: 8,
  document: 9
};
const getGlobal = function getGlobal2() {
  return typeof window === `\u0075\u006e\u0064\u0065\u0066\u0069\u006e\u0065\u0064` ? null : window;
};
const _createTrustedTypesPolicy = function _createTrustedTypesPolicy2(trustedTypes, purifyHostElement) {
  if (typeof trustedTypes !== `\u006f\u0062\u006a\u0065\u0063\u0074` || typeof trustedTypes.createPolicy !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
    return null;
  }
  let suffix = null;
  const ATTR_NAME = `\u0064\u0061\u0074\u0061\u002d\u0074\u0074\u002d\u0070\u006f\u006c\u0069\u0063\u0079\u002d\u0073\u0075\u0066\u0066\u0069\u0078`;
  if (purifyHostElement && purifyHostElement.hasAttribute(ATTR_NAME)) {
    suffix = purifyHostElement.getAttribute(ATTR_NAME);
  }
  const policyName = `\u0064\u006f\u006d\u0070\u0075\u0072\u0069\u0066\u0079` + (suffix ? `\u0023` + suffix : ``);
  try {
    return trustedTypes.createPolicy(policyName, {
      createHTML(html2) {
        return html2;
      },
      createScriptURL(scriptUrl) {
        return scriptUrl;
      }
    });
  } catch (_) {
    console.warn(`\u0054\u0072\u0075\u0073\u0074\u0065\u0064\u0054\u0079\u0070\u0065\u0073\u0020\u0070\u006f\u006c\u0069\u0063\u0079\u0020` + policyName + `\u0020\u0063\u006f\u0075\u006c\u0064\u0020\u006e\u006f\u0074\u0020\u0062\u0065\u0020\u0063\u0072\u0065\u0061\u0074\u0065\u0064\u002e`);
    return null;
  }
};
const _createHooksMap = function _createHooksMap2() {
  return {
    afterSanitizeAttributes: [],
    afterSanitizeElements: [],
    afterSanitizeShadowDOM: [],
    beforeSanitizeAttributes: [],
    beforeSanitizeElements: [],
    beforeSanitizeShadowDOM: [],
    uponSanitizeAttribute: [],
    uponSanitizeElement: [],
    uponSanitizeShadowNode: []
  };
};
function createDOMPurify() {
  let window2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : getGlobal();
  const DOMPurify = root => createDOMPurify(root);
  DOMPurify.version = `\u0033\u002e\u0032\u002e\u0036`;
  DOMPurify.removed = [];
  if (!window2 || !window2.document || window2.document.nodeType !== NODE_TYPE.document || !window2.Element) {
    DOMPurify.isSupported = false;
    return DOMPurify;
  }
  let {
    document
  } = window2;
  const originalDocument = document;
  const currentScript = originalDocument.currentScript;
  const {
    DocumentFragment,
    HTMLTemplateElement,
    Node,
    Element,
    NodeFilter,
    NamedNodeMap = window2.NamedNodeMap || window2.MozNamedAttrMap,
    HTMLFormElement,
    DOMParser,
    trustedTypes
  } = window2;
  const ElementPrototype = Element.prototype;
  const cloneNode = lookupGetter(ElementPrototype, `\u0063\u006c\u006f\u006e\u0065\u004e\u006f\u0064\u0065`);
  const remove = lookupGetter(ElementPrototype, `\u0072\u0065\u006d\u006f\u0076\u0065`);
  const getNextSibling = lookupGetter(ElementPrototype, `\u006e\u0065\u0078\u0074\u0053\u0069\u0062\u006c\u0069\u006e\u0067`);
  const getChildNodes = lookupGetter(ElementPrototype, `\u0063\u0068\u0069\u006c\u0064\u004e\u006f\u0064\u0065\u0073`);
  const getParentNode = lookupGetter(ElementPrototype, `\u0070\u0061\u0072\u0065\u006e\u0074\u004e\u006f\u0064\u0065`);
  if (typeof HTMLTemplateElement === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
    const template = document.createElement(`\u0074\u0065\u006d\u0070\u006c\u0061\u0074\u0065`);
    if (template.content && template.content.ownerDocument) {
      document = template.content.ownerDocument;
    }
  }
  let trustedTypesPolicy;
  let emptyHTML = ``;
  const {
    implementation,
    createNodeIterator,
    createDocumentFragment,
    getElementsByTagName
  } = document;
  const {
    importNode
  } = originalDocument;
  let hooks = _createHooksMap();
  DOMPurify.isSupported = typeof entries === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` && typeof getParentNode === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` && implementation && implementation.createHTMLDocument !== void 0;
  const {
    MUSTACHE_EXPR: MUSTACHE_EXPR2,
    ERB_EXPR: ERB_EXPR2,
    TMPLIT_EXPR: TMPLIT_EXPR2,
    DATA_ATTR: DATA_ATTR2,
    ARIA_ATTR: ARIA_ATTR2,
    IS_SCRIPT_OR_DATA: IS_SCRIPT_OR_DATA2,
    ATTR_WHITESPACE: ATTR_WHITESPACE2,
    CUSTOM_ELEMENT: CUSTOM_ELEMENT2
  } = EXPRESSIONS;
  let {
    IS_ALLOWED_URI: IS_ALLOWED_URI$1
  } = EXPRESSIONS;
  let ALLOWED_TAGS = null;
  const DEFAULT_ALLOWED_TAGS = addToSet({}, [...html$1, ...svg$1, ...svgFilters, ...mathMl$1, ...text]);
  let ALLOWED_ATTR = null;
  const DEFAULT_ALLOWED_ATTR = addToSet({}, [...html, ...svg, ...mathMl, ...xml]);
  let CUSTOM_ELEMENT_HANDLING = Object.seal(create(null, {
    tagNameCheck: {
      writable: true,
      configurable: false,
      enumerable: true,
      value: null
    },
    attributeNameCheck: {
      writable: true,
      configurable: false,
      enumerable: true,
      value: null
    },
    allowCustomizedBuiltInElements: {
      writable: true,
      configurable: false,
      enumerable: true,
      value: false
    }
  }));
  let FORBID_TAGS = null;
  let FORBID_ATTR = null;
  let ALLOW_ARIA_ATTR = true;
  let ALLOW_DATA_ATTR = true;
  let ALLOW_UNKNOWN_PROTOCOLS = false;
  let ALLOW_SELF_CLOSE_IN_ATTR = true;
  let SAFE_FOR_TEMPLATES = false;
  let SAFE_FOR_XML = true;
  let WHOLE_DOCUMENT = false;
  let SET_CONFIG = false;
  let FORCE_BODY = false;
  let RETURN_DOM = false;
  let RETURN_DOM_FRAGMENT = false;
  let RETURN_TRUSTED_TYPE = false;
  let SANITIZE_DOM = true;
  let SANITIZE_NAMED_PROPS = false;
  const SANITIZE_NAMED_PROPS_PREFIX = `\u0075\u0073\u0065\u0072\u002d\u0063\u006f\u006e\u0074\u0065\u006e\u0074\u002d`;
  let KEEP_CONTENT = true;
  let IN_PLACE = false;
  let USE_PROFILES = {};
  let FORBID_CONTENTS = null;
  const DEFAULT_FORBID_CONTENTS = addToSet({}, [`\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e\u002d\u0078\u006d\u006c`, `\u0061\u0075\u0064\u0069\u006f`, `\u0063\u006f\u006c\u0067\u0072\u006f\u0075\u0070`, `\u0064\u0065\u0073\u0063`, `\u0066\u006f\u0072\u0065\u0069\u0067\u006e\u006f\u0062\u006a\u0065\u0063\u0074`, `\u0068\u0065\u0061\u0064`, `\u0069\u0066\u0072\u0061\u006d\u0065`, `\u006d\u0061\u0074\u0068`, `\u006d\u0069`, `\u006d\u006e`, `\u006d\u006f`, `\u006d\u0073`, `\u006d\u0074\u0065\u0078\u0074`, `\u006e\u006f\u0065\u006d\u0062\u0065\u0064`, `\u006e\u006f\u0066\u0072\u0061\u006d\u0065\u0073`, `\u006e\u006f\u0073\u0063\u0072\u0069\u0070\u0074`, `\u0070\u006c\u0061\u0069\u006e\u0074\u0065\u0078\u0074`, `\u0073\u0063\u0072\u0069\u0070\u0074`, `\u0073\u0074\u0079\u006c\u0065`, `\u0073\u0076\u0067`, `\u0074\u0065\u006d\u0070\u006c\u0061\u0074\u0065`, `\u0074\u0068\u0065\u0061\u0064`, `\u0074\u0069\u0074\u006c\u0065`, `\u0076\u0069\u0064\u0065\u006f`, `\u0078\u006d\u0070`]);
  let DATA_URI_TAGS = null;
  const DEFAULT_DATA_URI_TAGS = addToSet({}, [`\u0061\u0075\u0064\u0069\u006f`, `\u0076\u0069\u0064\u0065\u006f`, `\u0069\u006d\u0067`, `\u0073\u006f\u0075\u0072\u0063\u0065`, `\u0069\u006d\u0061\u0067\u0065`, `\u0074\u0072\u0061\u0063\u006b`]);
  let URI_SAFE_ATTRIBUTES = null;
  const DEFAULT_URI_SAFE_ATTRIBUTES = addToSet({}, [`\u0061\u006c\u0074`, `\u0063\u006c\u0061\u0073\u0073`, `\u0066\u006f\u0072`, `\u0069\u0064`, `\u006c\u0061\u0062\u0065\u006c`, `\u006e\u0061\u006d\u0065`, `\u0070\u0061\u0074\u0074\u0065\u0072\u006e`, `\u0070\u006c\u0061\u0063\u0065\u0068\u006f\u006c\u0064\u0065\u0072`, `\u0072\u006f\u006c\u0065`, `\u0073\u0075\u006d\u006d\u0061\u0072\u0079`, `\u0074\u0069\u0074\u006c\u0065`, `\u0076\u0061\u006c\u0075\u0065`, `\u0073\u0074\u0079\u006c\u0065`, `\u0078\u006d\u006c\u006e\u0073`]);
  const MATHML_NAMESPACE = `\u0068\u0074\u0074\u0070\u003a\u002f\u002f\u0077\u0077\u0077\u002e\u0077\u0033\u002e\u006f\u0072\u0067\u002f\u0031\u0039\u0039\u0038\u002f\u004d\u0061\u0074\u0068\u002f\u004d\u0061\u0074\u0068\u004d\u004c`;
  const SVG_NAMESPACE = `\u0068\u0074\u0074\u0070\u003a\u002f\u002f\u0077\u0077\u0077\u002e\u0077\u0033\u002e\u006f\u0072\u0067\u002f\u0032\u0030\u0030\u0030\u002f\u0073\u0076\u0067`;
  const HTML_NAMESPACE = `\u0068\u0074\u0074\u0070\u003a\u002f\u002f\u0077\u0077\u0077\u002e\u0077\u0033\u002e\u006f\u0072\u0067\u002f\u0031\u0039\u0039\u0039\u002f\u0078\u0068\u0074\u006d\u006c`;
  let NAMESPACE = HTML_NAMESPACE;
  let IS_EMPTY_INPUT = false;
  let ALLOWED_NAMESPACES = null;
  const DEFAULT_ALLOWED_NAMESPACES = addToSet({}, [MATHML_NAMESPACE, SVG_NAMESPACE, HTML_NAMESPACE], stringToString);
  let MATHML_TEXT_INTEGRATION_POINTS = addToSet({}, [`\u006d\u0069`, `\u006d\u006f`, `\u006d\u006e`, `\u006d\u0073`, `\u006d\u0074\u0065\u0078\u0074`]);
  let HTML_INTEGRATION_POINTS = addToSet({}, [`\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e\u002d\u0078\u006d\u006c`]);
  const COMMON_SVG_AND_HTML_ELEMENTS = addToSet({}, [`\u0074\u0069\u0074\u006c\u0065`, `\u0073\u0074\u0079\u006c\u0065`, `\u0066\u006f\u006e\u0074`, `\u0061`, `\u0073\u0063\u0072\u0069\u0070\u0074`]);
  let PARSER_MEDIA_TYPE = null;
  const SUPPORTED_PARSER_MEDIA_TYPES = [`\u0061\u0070\u0070\u006c\u0069\u0063\u0061\u0074\u0069\u006f\u006e\u002f\u0078\u0068\u0074\u006d\u006c\u002b\u0078\u006d\u006c`, `\u0074\u0065\u0078\u0074\u002f\u0068\u0074\u006d\u006c`];
  const DEFAULT_PARSER_MEDIA_TYPE = `\u0074\u0065\u0078\u0074\u002f\u0068\u0074\u006d\u006c`;
  let transformCaseFunc = null;
  let CONFIG = null;
  const formElement = document.createElement(`\u0066\u006f\u0072\u006d`);
  const isRegexOrFunction = function isRegexOrFunction2(testValue) {
    return testValue instanceof RegExp || testValue instanceof Function;
  };
  const _parseConfig = function _parseConfig2() {
    let cfg = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    if (CONFIG && CONFIG === cfg) {
      return;
    }
    if (!cfg || typeof cfg !== `\u006f\u0062\u006a\u0065\u0063\u0074`) {
      cfg = {};
    }
    cfg = clone(cfg);
    PARSER_MEDIA_TYPE =
    // eslint-disable-next-line unicorn/prefer-includes
    SUPPORTED_PARSER_MEDIA_TYPES.indexOf(cfg.PARSER_MEDIA_TYPE) === -1 ? DEFAULT_PARSER_MEDIA_TYPE : cfg.PARSER_MEDIA_TYPE;
    transformCaseFunc = PARSER_MEDIA_TYPE === `\u0061\u0070\u0070\u006c\u0069\u0063\u0061\u0074\u0069\u006f\u006e\u002f\u0078\u0068\u0074\u006d\u006c\u002b\u0078\u006d\u006c` ? stringToString : stringToLowerCase;
    ALLOWED_TAGS = objectHasOwnProperty(cfg, `\u0041\u004c\u004c\u004f\u0057\u0045\u0044\u005f\u0054\u0041\u0047\u0053`) ? addToSet({}, cfg.ALLOWED_TAGS, transformCaseFunc) : DEFAULT_ALLOWED_TAGS;
    ALLOWED_ATTR = objectHasOwnProperty(cfg, `\u0041\u004c\u004c\u004f\u0057\u0045\u0044\u005f\u0041\u0054\u0054\u0052`) ? addToSet({}, cfg.ALLOWED_ATTR, transformCaseFunc) : DEFAULT_ALLOWED_ATTR;
    ALLOWED_NAMESPACES = objectHasOwnProperty(cfg, `\u0041\u004c\u004c\u004f\u0057\u0045\u0044\u005f\u004e\u0041\u004d\u0045\u0053\u0050\u0041\u0043\u0045\u0053`) ? addToSet({}, cfg.ALLOWED_NAMESPACES, stringToString) : DEFAULT_ALLOWED_NAMESPACES;
    URI_SAFE_ATTRIBUTES = objectHasOwnProperty(cfg, `\u0041\u0044\u0044\u005f\u0055\u0052\u0049\u005f\u0053\u0041\u0046\u0045\u005f\u0041\u0054\u0054\u0052`) ? addToSet(clone(DEFAULT_URI_SAFE_ATTRIBUTES), cfg.ADD_URI_SAFE_ATTR, transformCaseFunc) : DEFAULT_URI_SAFE_ATTRIBUTES;
    DATA_URI_TAGS = objectHasOwnProperty(cfg, `\u0041\u0044\u0044\u005f\u0044\u0041\u0054\u0041\u005f\u0055\u0052\u0049\u005f\u0054\u0041\u0047\u0053`) ? addToSet(clone(DEFAULT_DATA_URI_TAGS), cfg.ADD_DATA_URI_TAGS, transformCaseFunc) : DEFAULT_DATA_URI_TAGS;
    FORBID_CONTENTS = objectHasOwnProperty(cfg, `\u0046\u004f\u0052\u0042\u0049\u0044\u005f\u0043\u004f\u004e\u0054\u0045\u004e\u0054\u0053`) ? addToSet({}, cfg.FORBID_CONTENTS, transformCaseFunc) : DEFAULT_FORBID_CONTENTS;
    FORBID_TAGS = objectHasOwnProperty(cfg, `\u0046\u004f\u0052\u0042\u0049\u0044\u005f\u0054\u0041\u0047\u0053`) ? addToSet({}, cfg.FORBID_TAGS, transformCaseFunc) : clone({});
    FORBID_ATTR = objectHasOwnProperty(cfg, `\u0046\u004f\u0052\u0042\u0049\u0044\u005f\u0041\u0054\u0054\u0052`) ? addToSet({}, cfg.FORBID_ATTR, transformCaseFunc) : clone({});
    USE_PROFILES = objectHasOwnProperty(cfg, `\u0055\u0053\u0045\u005f\u0050\u0052\u004f\u0046\u0049\u004c\u0045\u0053`) ? cfg.USE_PROFILES : false;
    ALLOW_ARIA_ATTR = cfg.ALLOW_ARIA_ATTR !== false;
    ALLOW_DATA_ATTR = cfg.ALLOW_DATA_ATTR !== false;
    ALLOW_UNKNOWN_PROTOCOLS = cfg.ALLOW_UNKNOWN_PROTOCOLS || false;
    ALLOW_SELF_CLOSE_IN_ATTR = cfg.ALLOW_SELF_CLOSE_IN_ATTR !== false;
    SAFE_FOR_TEMPLATES = cfg.SAFE_FOR_TEMPLATES || false;
    SAFE_FOR_XML = cfg.SAFE_FOR_XML !== false;
    WHOLE_DOCUMENT = cfg.WHOLE_DOCUMENT || false;
    RETURN_DOM = cfg.RETURN_DOM || false;
    RETURN_DOM_FRAGMENT = cfg.RETURN_DOM_FRAGMENT || false;
    RETURN_TRUSTED_TYPE = cfg.RETURN_TRUSTED_TYPE || false;
    FORCE_BODY = cfg.FORCE_BODY || false;
    SANITIZE_DOM = cfg.SANITIZE_DOM !== false;
    SANITIZE_NAMED_PROPS = cfg.SANITIZE_NAMED_PROPS || false;
    KEEP_CONTENT = cfg.KEEP_CONTENT !== false;
    IN_PLACE = cfg.IN_PLACE || false;
    IS_ALLOWED_URI$1 = cfg.ALLOWED_URI_REGEXP || IS_ALLOWED_URI;
    NAMESPACE = cfg.NAMESPACE || HTML_NAMESPACE;
    MATHML_TEXT_INTEGRATION_POINTS = cfg.MATHML_TEXT_INTEGRATION_POINTS || MATHML_TEXT_INTEGRATION_POINTS;
    HTML_INTEGRATION_POINTS = cfg.HTML_INTEGRATION_POINTS || HTML_INTEGRATION_POINTS;
    CUSTOM_ELEMENT_HANDLING = cfg.CUSTOM_ELEMENT_HANDLING || {};
    if (cfg.CUSTOM_ELEMENT_HANDLING && isRegexOrFunction(cfg.CUSTOM_ELEMENT_HANDLING.tagNameCheck)) {
      CUSTOM_ELEMENT_HANDLING.tagNameCheck = cfg.CUSTOM_ELEMENT_HANDLING.tagNameCheck;
    }
    if (cfg.CUSTOM_ELEMENT_HANDLING && isRegexOrFunction(cfg.CUSTOM_ELEMENT_HANDLING.attributeNameCheck)) {
      CUSTOM_ELEMENT_HANDLING.attributeNameCheck = cfg.CUSTOM_ELEMENT_HANDLING.attributeNameCheck;
    }
    if (cfg.CUSTOM_ELEMENT_HANDLING && typeof cfg.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements === `\u0062\u006f\u006f\u006c\u0065\u0061\u006e`) {
      CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements = cfg.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements;
    }
    if (SAFE_FOR_TEMPLATES) {
      ALLOW_DATA_ATTR = false;
    }
    if (RETURN_DOM_FRAGMENT) {
      RETURN_DOM = true;
    }
    if (USE_PROFILES) {
      ALLOWED_TAGS = addToSet({}, text);
      ALLOWED_ATTR = [];
      if (USE_PROFILES.html === true) {
        addToSet(ALLOWED_TAGS, html$1);
        addToSet(ALLOWED_ATTR, html);
      }
      if (USE_PROFILES.svg === true) {
        addToSet(ALLOWED_TAGS, svg$1);
        addToSet(ALLOWED_ATTR, svg);
        addToSet(ALLOWED_ATTR, xml);
      }
      if (USE_PROFILES.svgFilters === true) {
        addToSet(ALLOWED_TAGS, svgFilters);
        addToSet(ALLOWED_ATTR, svg);
        addToSet(ALLOWED_ATTR, xml);
      }
      if (USE_PROFILES.mathMl === true) {
        addToSet(ALLOWED_TAGS, mathMl$1);
        addToSet(ALLOWED_ATTR, mathMl);
        addToSet(ALLOWED_ATTR, xml);
      }
    }
    if (cfg.ADD_TAGS) {
      if (ALLOWED_TAGS === DEFAULT_ALLOWED_TAGS) {
        ALLOWED_TAGS = clone(ALLOWED_TAGS);
      }
      addToSet(ALLOWED_TAGS, cfg.ADD_TAGS, transformCaseFunc);
    }
    if (cfg.ADD_ATTR) {
      if (ALLOWED_ATTR === DEFAULT_ALLOWED_ATTR) {
        ALLOWED_ATTR = clone(ALLOWED_ATTR);
      }
      addToSet(ALLOWED_ATTR, cfg.ADD_ATTR, transformCaseFunc);
    }
    if (cfg.ADD_URI_SAFE_ATTR) {
      addToSet(URI_SAFE_ATTRIBUTES, cfg.ADD_URI_SAFE_ATTR, transformCaseFunc);
    }
    if (cfg.FORBID_CONTENTS) {
      if (FORBID_CONTENTS === DEFAULT_FORBID_CONTENTS) {
        FORBID_CONTENTS = clone(FORBID_CONTENTS);
      }
      addToSet(FORBID_CONTENTS, cfg.FORBID_CONTENTS, transformCaseFunc);
    }
    if (KEEP_CONTENT) {
      ALLOWED_TAGS[`\u0023\u0074\u0065\u0078\u0074`] = true;
    }
    if (WHOLE_DOCUMENT) {
      addToSet(ALLOWED_TAGS, [`\u0068\u0074\u006d\u006c`, `\u0068\u0065\u0061\u0064`, `\u0062\u006f\u0064\u0079`]);
    }
    if (ALLOWED_TAGS.table) {
      addToSet(ALLOWED_TAGS, [`\u0074\u0062\u006f\u0064\u0079`]);
      delete FORBID_TAGS.tbody;
    }
    if (cfg.TRUSTED_TYPES_POLICY) {
      if (typeof cfg.TRUSTED_TYPES_POLICY.createHTML !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
        throw typeErrorCreate(`\u0054\u0052\u0055\u0053\u0054\u0045\u0044\u005f\u0054\u0059\u0050\u0045\u0053\u005f\u0050\u004f\u004c\u0049\u0043\u0059\u0020\u0063\u006f\u006e\u0066\u0069\u0067\u0075\u0072\u0061\u0074\u0069\u006f\u006e\u0020\u006f\u0070\u0074\u0069\u006f\u006e\u0020\u006d\u0075\u0073\u0074\u0020\u0070\u0072\u006f\u0076\u0069\u0064\u0065\u0020\u0061\u0020\u0022\u0063\u0072\u0065\u0061\u0074\u0065\u0048\u0054\u004d\u004c\u0022\u0020\u0068\u006f\u006f\u006b\u002e`);
      }
      if (typeof cfg.TRUSTED_TYPES_POLICY.createScriptURL !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
        throw typeErrorCreate(`\u0054\u0052\u0055\u0053\u0054\u0045\u0044\u005f\u0054\u0059\u0050\u0045\u0053\u005f\u0050\u004f\u004c\u0049\u0043\u0059\u0020\u0063\u006f\u006e\u0066\u0069\u0067\u0075\u0072\u0061\u0074\u0069\u006f\u006e\u0020\u006f\u0070\u0074\u0069\u006f\u006e\u0020\u006d\u0075\u0073\u0074\u0020\u0070\u0072\u006f\u0076\u0069\u0064\u0065\u0020\u0061\u0020\u0022\u0063\u0072\u0065\u0061\u0074\u0065\u0053\u0063\u0072\u0069\u0070\u0074\u0055\u0052\u004c\u0022\u0020\u0068\u006f\u006f\u006b\u002e`);
      }
      trustedTypesPolicy = cfg.TRUSTED_TYPES_POLICY;
      emptyHTML = trustedTypesPolicy.createHTML(``);
    } else {
      if (trustedTypesPolicy === void 0) {
        trustedTypesPolicy = _createTrustedTypesPolicy(trustedTypes, currentScript);
      }
      if (trustedTypesPolicy !== null && typeof emptyHTML === `\u0073\u0074\u0072\u0069\u006e\u0067`) {
        emptyHTML = trustedTypesPolicy.createHTML(``);
      }
    }
    if (freeze) {
      freeze(cfg);
    }
    CONFIG = cfg;
  };
  const ALL_SVG_TAGS = addToSet({}, [...svg$1, ...svgFilters, ...svgDisallowed]);
  const ALL_MATHML_TAGS = addToSet({}, [...mathMl$1, ...mathMlDisallowed]);
  const _checkValidNamespace = function _checkValidNamespace2(element) {
    let parent = getParentNode(element);
    if (!parent || !parent.tagName) {
      parent = {
        namespaceURI: NAMESPACE,
        tagName: `\u0074\u0065\u006d\u0070\u006c\u0061\u0074\u0065`
      };
    }
    const tagName = stringToLowerCase(element.tagName);
    const parentTagName = stringToLowerCase(parent.tagName);
    if (!ALLOWED_NAMESPACES[element.namespaceURI]) {
      return false;
    }
    if (element.namespaceURI === SVG_NAMESPACE) {
      if (parent.namespaceURI === HTML_NAMESPACE) {
        return tagName === `\u0073\u0076\u0067`;
      }
      if (parent.namespaceURI === MATHML_NAMESPACE) {
        return tagName === `\u0073\u0076\u0067` && (parentTagName === `\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e\u002d\u0078\u006d\u006c` || MATHML_TEXT_INTEGRATION_POINTS[parentTagName]);
      }
      return Boolean(ALL_SVG_TAGS[tagName]);
    }
    if (element.namespaceURI === MATHML_NAMESPACE) {
      if (parent.namespaceURI === HTML_NAMESPACE) {
        return tagName === `\u006d\u0061\u0074\u0068`;
      }
      if (parent.namespaceURI === SVG_NAMESPACE) {
        return tagName === `\u006d\u0061\u0074\u0068` && HTML_INTEGRATION_POINTS[parentTagName];
      }
      return Boolean(ALL_MATHML_TAGS[tagName]);
    }
    if (element.namespaceURI === HTML_NAMESPACE) {
      if (parent.namespaceURI === SVG_NAMESPACE && !HTML_INTEGRATION_POINTS[parentTagName]) {
        return false;
      }
      if (parent.namespaceURI === MATHML_NAMESPACE && !MATHML_TEXT_INTEGRATION_POINTS[parentTagName]) {
        return false;
      }
      return !ALL_MATHML_TAGS[tagName] && (COMMON_SVG_AND_HTML_ELEMENTS[tagName] || !ALL_SVG_TAGS[tagName]);
    }
    if (PARSER_MEDIA_TYPE === `\u0061\u0070\u0070\u006c\u0069\u0063\u0061\u0074\u0069\u006f\u006e\u002f\u0078\u0068\u0074\u006d\u006c\u002b\u0078\u006d\u006c` && ALLOWED_NAMESPACES[element.namespaceURI]) {
      return true;
    }
    return false;
  };
  const _forceRemove = function _forceRemove2(node) {
    arrayPush(DOMPurify.removed, {
      element: node
    });
    try {
      getParentNode(node).removeChild(node);
    } catch (_) {
      remove(node);
    }
  };
  const _removeAttribute = function _removeAttribute2(name, element) {
    try {
      arrayPush(DOMPurify.removed, {
        attribute: element.getAttributeNode(name),
        from: element
      });
    } catch (_) {
      arrayPush(DOMPurify.removed, {
        attribute: null,
        from: element
      });
    }
    element.removeAttribute(name);
    if (name === `\u0069\u0073`) {
      if (RETURN_DOM || RETURN_DOM_FRAGMENT) {
        try {
          _forceRemove(element);
        } catch (_) {}
      } else {
        try {
          element.setAttribute(name, ``);
        } catch (_) {}
      }
    }
  };
  const _initDocument = function _initDocument2(dirty) {
    let doc = null;
    let leadingWhitespace = null;
    if (FORCE_BODY) {
      dirty = `\u003c\u0072\u0065\u006d\u006f\u0076\u0065\u003e\u003c\u002f\u0072\u0065\u006d\u006f\u0076\u0065\u003e` + dirty;
    } else {
      const matches = stringMatch(dirty, /^[\r\n\t ]+/);
      leadingWhitespace = matches && matches[0];
    }
    if (PARSER_MEDIA_TYPE === `\u0061\u0070\u0070\u006c\u0069\u0063\u0061\u0074\u0069\u006f\u006e\u002f\u0078\u0068\u0074\u006d\u006c\u002b\u0078\u006d\u006c` && NAMESPACE === HTML_NAMESPACE) {
      dirty = `\u003c\u0068\u0074\u006d\u006c\u0020\u0078\u006d\u006c\u006e\u0073\u003d\u0022\u0068\u0074\u0074\u0070\u003a\u002f\u002f\u0077\u0077\u0077\u002e\u0077\u0033\u002e\u006f\u0072\u0067\u002f\u0031\u0039\u0039\u0039\u002f\u0078\u0068\u0074\u006d\u006c\u0022\u003e\u003c\u0068\u0065\u0061\u0064\u003e\u003c\u002f\u0068\u0065\u0061\u0064\u003e\u003c\u0062\u006f\u0064\u0079\u003e` + dirty + `\u003c\u002f\u0062\u006f\u0064\u0079\u003e\u003c\u002f\u0068\u0074\u006d\u006c\u003e`;
    }
    const dirtyPayload = trustedTypesPolicy ? trustedTypesPolicy.createHTML(dirty) : dirty;
    if (NAMESPACE === HTML_NAMESPACE) {
      try {
        doc = new DOMParser().parseFromString(dirtyPayload, PARSER_MEDIA_TYPE);
      } catch (_) {}
    }
    if (!doc || !doc.documentElement) {
      doc = implementation.createDocument(NAMESPACE, `\u0074\u0065\u006d\u0070\u006c\u0061\u0074\u0065`, null);
      try {
        doc.documentElement.innerHTML = IS_EMPTY_INPUT ? emptyHTML : dirtyPayload;
      } catch (_) {}
    }
    const body = doc.body || doc.documentElement;
    if (dirty && leadingWhitespace) {
      body.insertBefore(document.createTextNode(leadingWhitespace), body.childNodes[0] || null);
    }
    if (NAMESPACE === HTML_NAMESPACE) {
      return getElementsByTagName.call(doc, WHOLE_DOCUMENT ? `\u0068\u0074\u006d\u006c` : `\u0062\u006f\u0064\u0079`)[0];
    }
    return WHOLE_DOCUMENT ? doc.documentElement : body;
  };
  const _createNodeIterator = function _createNodeIterator2(root) {
    return createNodeIterator.call(root.ownerDocument || root, root,
    // eslint-disable-next-line no-bitwise
    NodeFilter.SHOW_ELEMENT | NodeFilter.SHOW_COMMENT | NodeFilter.SHOW_TEXT | NodeFilter.SHOW_PROCESSING_INSTRUCTION | NodeFilter.SHOW_CDATA_SECTION, null);
  };
  const _isClobbered = function _isClobbered2(element) {
    return element instanceof HTMLFormElement && (typeof element.nodeName !== `\u0073\u0074\u0072\u0069\u006e\u0067` || typeof element.textContent !== `\u0073\u0074\u0072\u0069\u006e\u0067` || typeof element.removeChild !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` || !(element.attributes instanceof NamedNodeMap) || typeof element.removeAttribute !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` || typeof element.setAttribute !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` || typeof element.namespaceURI !== `\u0073\u0074\u0072\u0069\u006e\u0067` || typeof element.insertBefore !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` || typeof element.hasChildNodes !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`);
  };
  const _isNode = function _isNode2(value) {
    return typeof Node === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e` && value instanceof Node;
  };
  function _executeHooks(hooks2, currentNode, data) {
    arrayForEach(hooks2, hook => {
      hook.call(DOMPurify, currentNode, data, CONFIG);
    });
  }
  const _sanitizeElements = function _sanitizeElements2(currentNode) {
    let content = null;
    _executeHooks(hooks.beforeSanitizeElements, currentNode, null);
    if (_isClobbered(currentNode)) {
      _forceRemove(currentNode);
      return true;
    }
    const tagName = transformCaseFunc(currentNode.nodeName);
    _executeHooks(hooks.uponSanitizeElement, currentNode, {
      tagName,
      allowedTags: ALLOWED_TAGS
    });
    if (SAFE_FOR_XML && currentNode.hasChildNodes() && !_isNode(currentNode.firstElementChild) && regExpTest(/<[/\w!]/g, currentNode.innerHTML) && regExpTest(/<[/\w!]/g, currentNode.textContent)) {
      _forceRemove(currentNode);
      return true;
    }
    if (currentNode.nodeType === NODE_TYPE.progressingInstruction) {
      _forceRemove(currentNode);
      return true;
    }
    if (SAFE_FOR_XML && currentNode.nodeType === NODE_TYPE.comment && regExpTest(/<[/\w]/g, currentNode.data)) {
      _forceRemove(currentNode);
      return true;
    }
    if (!ALLOWED_TAGS[tagName] || FORBID_TAGS[tagName]) {
      if (!FORBID_TAGS[tagName] && _isBasicCustomElement(tagName)) {
        if (CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof RegExp && regExpTest(CUSTOM_ELEMENT_HANDLING.tagNameCheck, tagName)) {
          return false;
        }
        if (CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof Function && CUSTOM_ELEMENT_HANDLING.tagNameCheck(tagName)) {
          return false;
        }
      }
      if (KEEP_CONTENT && !FORBID_CONTENTS[tagName]) {
        const parentNode = getParentNode(currentNode) || currentNode.parentNode;
        const childNodes = getChildNodes(currentNode) || currentNode.childNodes;
        if (childNodes && parentNode) {
          const childCount = childNodes.length;
          for (let i = childCount - 1; i >= 0; --i) {
            const childClone = cloneNode(childNodes[i], true);
            childClone.__removalCount = (currentNode.__removalCount || 0) + 1;
            parentNode.insertBefore(childClone, getNextSibling(currentNode));
          }
        }
      }
      _forceRemove(currentNode);
      return true;
    }
    if (currentNode instanceof Element && !_checkValidNamespace(currentNode)) {
      _forceRemove(currentNode);
      return true;
    }
    if ((tagName === `\u006e\u006f\u0073\u0063\u0072\u0069\u0070\u0074` || tagName === `\u006e\u006f\u0065\u006d\u0062\u0065\u0064` || tagName === `\u006e\u006f\u0066\u0072\u0061\u006d\u0065\u0073`) && regExpTest(/<\/no(script|embed|frames)/i, currentNode.innerHTML)) {
      _forceRemove(currentNode);
      return true;
    }
    if (SAFE_FOR_TEMPLATES && currentNode.nodeType === NODE_TYPE.text) {
      content = currentNode.textContent;
      arrayForEach([MUSTACHE_EXPR2, ERB_EXPR2, TMPLIT_EXPR2], expr => {
        content = stringReplace(content, expr, `\u0020`);
      });
      if (currentNode.textContent !== content) {
        arrayPush(DOMPurify.removed, {
          element: currentNode.cloneNode()
        });
        currentNode.textContent = content;
      }
    }
    _executeHooks(hooks.afterSanitizeElements, currentNode, null);
    return false;
  };
  const _isValidAttribute = function _isValidAttribute2(lcTag, lcName, value) {
    if (SANITIZE_DOM && (lcName === `\u0069\u0064` || lcName === `\u006e\u0061\u006d\u0065`) && (value in document || value in formElement)) {
      return false;
    }
    if (ALLOW_DATA_ATTR && !FORBID_ATTR[lcName] && regExpTest(DATA_ATTR2, lcName)) ;else if (ALLOW_ARIA_ATTR && regExpTest(ARIA_ATTR2, lcName)) ;else if (!ALLOWED_ATTR[lcName] || FORBID_ATTR[lcName]) {
      if (
      // First condition does a very basic check if a) it's basically a valid custom element tagname AND
      // b) if the tagName passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
      // and c) if the attribute name passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.attributeNameCheck
      _isBasicCustomElement(lcTag) && (CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof RegExp && regExpTest(CUSTOM_ELEMENT_HANDLING.tagNameCheck, lcTag) || CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof Function && CUSTOM_ELEMENT_HANDLING.tagNameCheck(lcTag)) && (CUSTOM_ELEMENT_HANDLING.attributeNameCheck instanceof RegExp && regExpTest(CUSTOM_ELEMENT_HANDLING.attributeNameCheck, lcName) || CUSTOM_ELEMENT_HANDLING.attributeNameCheck instanceof Function && CUSTOM_ELEMENT_HANDLING.attributeNameCheck(lcName)) ||
      // Alternative, second condition checks if it's an `is`-attribute, AND
      // the value passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
      lcName === `\u0069\u0073` && CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements && (CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof RegExp && regExpTest(CUSTOM_ELEMENT_HANDLING.tagNameCheck, value) || CUSTOM_ELEMENT_HANDLING.tagNameCheck instanceof Function && CUSTOM_ELEMENT_HANDLING.tagNameCheck(value))) ;else {
        return false;
      }
    } else if (URI_SAFE_ATTRIBUTES[lcName]) ;else if (regExpTest(IS_ALLOWED_URI$1, stringReplace(value, ATTR_WHITESPACE2, ``))) ;else if ((lcName === `\u0073\u0072\u0063` || lcName === `\u0078\u006c\u0069\u006e\u006b\u003a\u0068\u0072\u0065\u0066` || lcName === `\u0068\u0072\u0065\u0066`) && lcTag !== `\u0073\u0063\u0072\u0069\u0070\u0074` && stringIndexOf(value, `\u0064\u0061\u0074\u0061\u003a`) === 0 && DATA_URI_TAGS[lcTag]) ;else if (ALLOW_UNKNOWN_PROTOCOLS && !regExpTest(IS_SCRIPT_OR_DATA2, stringReplace(value, ATTR_WHITESPACE2, ``))) ;else if (value) {
      return false;
    } else ;
    return true;
  };
  const _isBasicCustomElement = function _isBasicCustomElement2(tagName) {
    return tagName !== `\u0061\u006e\u006e\u006f\u0074\u0061\u0074\u0069\u006f\u006e\u002d\u0078\u006d\u006c` && stringMatch(tagName, CUSTOM_ELEMENT2);
  };
  const _sanitizeAttributes = function _sanitizeAttributes2(currentNode) {
    _executeHooks(hooks.beforeSanitizeAttributes, currentNode, null);
    const {
      attributes
    } = currentNode;
    if (!attributes || _isClobbered(currentNode)) {
      return;
    }
    const hookEvent = {
      attrName: ``,
      attrValue: ``,
      keepAttr: true,
      allowedAttributes: ALLOWED_ATTR,
      forceKeepAttr: void 0
    };
    let l = attributes.length;
    while (l--) {
      const attr = attributes[l];
      const {
        name,
        namespaceURI,
        value: attrValue
      } = attr;
      const lcName = transformCaseFunc(name);
      const initValue = attrValue;
      let value = name === `\u0076\u0061\u006c\u0075\u0065` ? initValue : stringTrim(initValue);
      hookEvent.attrName = lcName;
      hookEvent.attrValue = value;
      hookEvent.keepAttr = true;
      hookEvent.forceKeepAttr = void 0;
      _executeHooks(hooks.uponSanitizeAttribute, currentNode, hookEvent);
      value = hookEvent.attrValue;
      if (SANITIZE_NAMED_PROPS && (lcName === `\u0069\u0064` || lcName === `\u006e\u0061\u006d\u0065`)) {
        _removeAttribute(name, currentNode);
        value = SANITIZE_NAMED_PROPS_PREFIX + value;
      }
      if (SAFE_FOR_XML && regExpTest(/((--!?|])>)|<\/(style|title)/i, value)) {
        _removeAttribute(name, currentNode);
        continue;
      }
      if (hookEvent.forceKeepAttr) {
        continue;
      }
      if (!hookEvent.keepAttr) {
        _removeAttribute(name, currentNode);
        continue;
      }
      if (!ALLOW_SELF_CLOSE_IN_ATTR && regExpTest(/\/>/i, value)) {
        _removeAttribute(name, currentNode);
        continue;
      }
      if (SAFE_FOR_TEMPLATES) {
        arrayForEach([MUSTACHE_EXPR2, ERB_EXPR2, TMPLIT_EXPR2], expr => {
          value = stringReplace(value, expr, `\u0020`);
        });
      }
      const lcTag = transformCaseFunc(currentNode.nodeName);
      if (!_isValidAttribute(lcTag, lcName, value)) {
        _removeAttribute(name, currentNode);
        continue;
      }
      if (trustedTypesPolicy && typeof trustedTypes === `\u006f\u0062\u006a\u0065\u0063\u0074` && typeof trustedTypes.getAttributeType === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
        if (namespaceURI) ;else {
          switch (trustedTypes.getAttributeType(lcTag, lcName)) {
            case `\u0054\u0072\u0075\u0073\u0074\u0065\u0064\u0048\u0054\u004d\u004c`:
              {
                value = trustedTypesPolicy.createHTML(value);
                break;
              }
            case `\u0054\u0072\u0075\u0073\u0074\u0065\u0064\u0053\u0063\u0072\u0069\u0070\u0074\u0055\u0052\u004c`:
              {
                value = trustedTypesPolicy.createScriptURL(value);
                break;
              }
          }
        }
      }
      if (value !== initValue) {
        try {
          if (namespaceURI) {
            currentNode.setAttributeNS(namespaceURI, name, value);
          } else {
            currentNode.setAttribute(name, value);
          }
          if (_isClobbered(currentNode)) {
            _forceRemove(currentNode);
          } else {
            arrayPop(DOMPurify.removed);
          }
        } catch (_) {
          _removeAttribute(name, currentNode);
        }
      }
    }
    _executeHooks(hooks.afterSanitizeAttributes, currentNode, null);
  };
  const _sanitizeShadowDOM = function _sanitizeShadowDOM2(fragment) {
    let shadowNode = null;
    const shadowIterator = _createNodeIterator(fragment);
    _executeHooks(hooks.beforeSanitizeShadowDOM, fragment, null);
    while (shadowNode = shadowIterator.nextNode()) {
      _executeHooks(hooks.uponSanitizeShadowNode, shadowNode, null);
      _sanitizeElements(shadowNode);
      _sanitizeAttributes(shadowNode);
      if (shadowNode.content instanceof DocumentFragment) {
        _sanitizeShadowDOM2(shadowNode.content);
      }
    }
    _executeHooks(hooks.afterSanitizeShadowDOM, fragment, null);
  };
  DOMPurify.sanitize = function (dirty) {
    let cfg = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    let body = null;
    let importedNode = null;
    let currentNode = null;
    let returnNode = null;
    IS_EMPTY_INPUT = !dirty;
    if (IS_EMPTY_INPUT) {
      dirty = `\u003c\u0021\u002d\u002d\u003e`;
    }
    if (typeof dirty !== `\u0073\u0074\u0072\u0069\u006e\u0067` && !_isNode(dirty)) {
      if (typeof dirty.toString === `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
        dirty = dirty.toString();
        if (typeof dirty !== `\u0073\u0074\u0072\u0069\u006e\u0067`) {
          throw typeErrorCreate(`\u0064\u0069\u0072\u0074\u0079\u0020\u0069\u0073\u0020\u006e\u006f\u0074\u0020\u0061\u0020\u0073\u0074\u0072\u0069\u006e\u0067\u002c\u0020\u0061\u0062\u006f\u0072\u0074\u0069\u006e\u0067`);
        }
      } else {
        throw typeErrorCreate(`\u0074\u006f\u0053\u0074\u0072\u0069\u006e\u0067\u0020\u0069\u0073\u0020\u006e\u006f\u0074\u0020\u0061\u0020\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`);
      }
    }
    if (!DOMPurify.isSupported) {
      return dirty;
    }
    if (!SET_CONFIG) {
      _parseConfig(cfg);
    }
    DOMPurify.removed = [];
    if (typeof dirty === `\u0073\u0074\u0072\u0069\u006e\u0067`) {
      IN_PLACE = false;
    }
    if (IN_PLACE) {
      if (dirty.nodeName) {
        const tagName = transformCaseFunc(dirty.nodeName);
        if (!ALLOWED_TAGS[tagName] || FORBID_TAGS[tagName]) {
          throw typeErrorCreate(`\u0072\u006f\u006f\u0074\u0020\u006e\u006f\u0064\u0065\u0020\u0069\u0073\u0020\u0066\u006f\u0072\u0062\u0069\u0064\u0064\u0065\u006e\u0020\u0061\u006e\u0064\u0020\u0063\u0061\u006e\u006e\u006f\u0074\u0020\u0062\u0065\u0020\u0073\u0061\u006e\u0069\u0074\u0069\u007a\u0065\u0064\u0020\u0069\u006e\u002d\u0070\u006c\u0061\u0063\u0065`);
        }
      }
    } else if (dirty instanceof Node) {
      body = _initDocument(`\u003c\u0021\u002d\u002d\u002d\u002d\u003e`);
      importedNode = body.ownerDocument.importNode(dirty, true);
      if (importedNode.nodeType === NODE_TYPE.element && importedNode.nodeName === `\u0042\u004f\u0044\u0059`) {
        body = importedNode;
      } else if (importedNode.nodeName === `\u0048\u0054\u004d\u004c`) {
        body = importedNode;
      } else {
        body.appendChild(importedNode);
      }
    } else {
      if (!RETURN_DOM && !SAFE_FOR_TEMPLATES && !WHOLE_DOCUMENT &&
      // eslint-disable-next-line unicorn/prefer-includes
      dirty.indexOf(`\u003c`) === -1) {
        return trustedTypesPolicy && RETURN_TRUSTED_TYPE ? trustedTypesPolicy.createHTML(dirty) : dirty;
      }
      body = _initDocument(dirty);
      if (!body) {
        return RETURN_DOM ? null : RETURN_TRUSTED_TYPE ? emptyHTML : ``;
      }
    }
    if (body && FORCE_BODY) {
      _forceRemove(body.firstChild);
    }
    const nodeIterator = _createNodeIterator(IN_PLACE ? dirty : body);
    while (currentNode = nodeIterator.nextNode()) {
      _sanitizeElements(currentNode);
      _sanitizeAttributes(currentNode);
      if (currentNode.content instanceof DocumentFragment) {
        _sanitizeShadowDOM(currentNode.content);
      }
    }
    if (IN_PLACE) {
      return dirty;
    }
    if (RETURN_DOM) {
      if (RETURN_DOM_FRAGMENT) {
        returnNode = createDocumentFragment.call(body.ownerDocument);
        while (body.firstChild) {
          returnNode.appendChild(body.firstChild);
        }
      } else {
        returnNode = body;
      }
      if (ALLOWED_ATTR.shadowroot || ALLOWED_ATTR.shadowrootmode) {
        returnNode = importNode.call(originalDocument, returnNode, true);
      }
      return returnNode;
    }
    let serializedHTML = WHOLE_DOCUMENT ? body.outerHTML : body.innerHTML;
    if (WHOLE_DOCUMENT && ALLOWED_TAGS[`\u0021\u0064\u006f\u0063\u0074\u0079\u0070\u0065`] && body.ownerDocument && body.ownerDocument.doctype && body.ownerDocument.doctype.name && regExpTest(DOCTYPE_NAME, body.ownerDocument.doctype.name)) {
      serializedHTML = `\u003c\u0021\u0044\u004f\u0043\u0054\u0059\u0050\u0045\u0020` + body.ownerDocument.doctype.name + `\u003e\u000a` + serializedHTML;
    }
    if (SAFE_FOR_TEMPLATES) {
      arrayForEach([MUSTACHE_EXPR2, ERB_EXPR2, TMPLIT_EXPR2], expr => {
        serializedHTML = stringReplace(serializedHTML, expr, `\u0020`);
      });
    }
    return trustedTypesPolicy && RETURN_TRUSTED_TYPE ? trustedTypesPolicy.createHTML(serializedHTML) : serializedHTML;
  };
  DOMPurify.setConfig = function () {
    let cfg = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    _parseConfig(cfg);
    SET_CONFIG = true;
  };
  DOMPurify.clearConfig = function () {
    CONFIG = null;
    SET_CONFIG = false;
  };
  DOMPurify.isValidAttribute = function (tag, attr, value) {
    if (!CONFIG) {
      _parseConfig({});
    }
    const lcTag = transformCaseFunc(tag);
    const lcName = transformCaseFunc(attr);
    return _isValidAttribute(lcTag, lcName, value);
  };
  DOMPurify.addHook = function (entryPoint, hookFunction) {
    if (typeof hookFunction !== `\u0066\u0075\u006e\u0063\u0074\u0069\u006f\u006e`) {
      return;
    }
    arrayPush(hooks[entryPoint], hookFunction);
  };
  DOMPurify.removeHook = function (entryPoint, hookFunction) {
    if (hookFunction !== void 0) {
      const index = arrayLastIndexOf(hooks[entryPoint], hookFunction);
      return index === -1 ? void 0 : arraySplice(hooks[entryPoint], index, 1)[0];
    }
    return arrayPop(hooks[entryPoint]);
  };
  DOMPurify.removeHooks = function (entryPoint) {
    hooks[entryPoint] = [];
  };
  DOMPurify.removeAllHooks = function () {
    hooks = _createHooksMap();
  };
  return DOMPurify;
}
var purify = createDOMPurify();
export { purify as default };